Class: Aws::Omics::Types::BatchListItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::BatchListItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
A summary of a batch returned by ListBatch.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the batch was created.
-
#id ⇒ String
The batch identifier.
-
#name ⇒ String
The batch name.
-
#status ⇒ String
The current batch status.
-
#total_runs ⇒ Integer
The total number of runs in the batch.
-
#workflow_id ⇒ String
The identifier of the workflow used for the batch.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the batch was created.
437 438 439 440 441 442 443 444 445 446 |
# File 'lib/aws-sdk-omics/types.rb', line 437 class BatchListItem < Struct.new( :id, :name, :status, :created_at, :total_runs, :workflow_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The batch identifier.
437 438 439 440 441 442 443 444 445 446 |
# File 'lib/aws-sdk-omics/types.rb', line 437 class BatchListItem < Struct.new( :id, :name, :status, :created_at, :total_runs, :workflow_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The batch name.
437 438 439 440 441 442 443 444 445 446 |
# File 'lib/aws-sdk-omics/types.rb', line 437 class BatchListItem < Struct.new( :id, :name, :status, :created_at, :total_runs, :workflow_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current batch status.
437 438 439 440 441 442 443 444 445 446 |
# File 'lib/aws-sdk-omics/types.rb', line 437 class BatchListItem < Struct.new( :id, :name, :status, :created_at, :total_runs, :workflow_id) SENSITIVE = [] include Aws::Structure end |
#total_runs ⇒ Integer
The total number of runs in the batch.
437 438 439 440 441 442 443 444 445 446 |
# File 'lib/aws-sdk-omics/types.rb', line 437 class BatchListItem < Struct.new( :id, :name, :status, :created_at, :total_runs, :workflow_id) SENSITIVE = [] include Aws::Structure end |
#workflow_id ⇒ String
The identifier of the workflow used for the batch.
437 438 439 440 441 442 443 444 445 446 |
# File 'lib/aws-sdk-omics/types.rb', line 437 class BatchListItem < Struct.new( :id, :name, :status, :created_at, :total_runs, :workflow_id) SENSITIVE = [] include Aws::Structure end |