Class: Aws::Omics::Types::CreateMultipartReadSetUploadResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::CreateMultipartReadSetUploadResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The creation time of the multipart upload.
-
#description ⇒ String
The description of the read set.
-
#generated_from ⇒ String
The source of the read set.
-
#name ⇒ String
The name of the read set.
-
#reference_arn ⇒ String
The read set source's reference ARN.
-
#sample_id ⇒ String
The source's sample ID.
-
#sequence_store_id ⇒ String
The sequence store ID for the store that the read set will be created in.
-
#source_file_type ⇒ String
The file type of the read set source.
-
#subject_id ⇒ String
The source's subject ID.
-
#tags ⇒ Hash<String,String>
The tags to add to the read set.
-
#upload_id ⇒ String
The ID for the initiated multipart upload.
Instance Attribute Details
#creation_time ⇒ Time
The creation time of the multipart upload.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 |
# File 'lib/aws-sdk-omics/types.rb', line 1073 class CreateMultipartReadSetUploadResponse < Struct.new( :sequence_store_id, :upload_id, :source_file_type, :subject_id, :sample_id, :generated_from, :reference_arn, :name, :description, :tags, :creation_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the read set.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 |
# File 'lib/aws-sdk-omics/types.rb', line 1073 class CreateMultipartReadSetUploadResponse < Struct.new( :sequence_store_id, :upload_id, :source_file_type, :subject_id, :sample_id, :generated_from, :reference_arn, :name, :description, :tags, :creation_time) SENSITIVE = [] include Aws::Structure end |
#generated_from ⇒ String
The source of the read set.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 |
# File 'lib/aws-sdk-omics/types.rb', line 1073 class CreateMultipartReadSetUploadResponse < Struct.new( :sequence_store_id, :upload_id, :source_file_type, :subject_id, :sample_id, :generated_from, :reference_arn, :name, :description, :tags, :creation_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the read set.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 |
# File 'lib/aws-sdk-omics/types.rb', line 1073 class CreateMultipartReadSetUploadResponse < Struct.new( :sequence_store_id, :upload_id, :source_file_type, :subject_id, :sample_id, :generated_from, :reference_arn, :name, :description, :tags, :creation_time) SENSITIVE = [] include Aws::Structure end |
#reference_arn ⇒ String
The read set source's reference ARN.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 |
# File 'lib/aws-sdk-omics/types.rb', line 1073 class CreateMultipartReadSetUploadResponse < Struct.new( :sequence_store_id, :upload_id, :source_file_type, :subject_id, :sample_id, :generated_from, :reference_arn, :name, :description, :tags, :creation_time) SENSITIVE = [] include Aws::Structure end |
#sample_id ⇒ String
The source's sample ID.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 |
# File 'lib/aws-sdk-omics/types.rb', line 1073 class CreateMultipartReadSetUploadResponse < Struct.new( :sequence_store_id, :upload_id, :source_file_type, :subject_id, :sample_id, :generated_from, :reference_arn, :name, :description, :tags, :creation_time) SENSITIVE = [] include Aws::Structure end |
#sequence_store_id ⇒ String
The sequence store ID for the store that the read set will be created in.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 |
# File 'lib/aws-sdk-omics/types.rb', line 1073 class CreateMultipartReadSetUploadResponse < Struct.new( :sequence_store_id, :upload_id, :source_file_type, :subject_id, :sample_id, :generated_from, :reference_arn, :name, :description, :tags, :creation_time) SENSITIVE = [] include Aws::Structure end |
#source_file_type ⇒ String
The file type of the read set source.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 |
# File 'lib/aws-sdk-omics/types.rb', line 1073 class CreateMultipartReadSetUploadResponse < Struct.new( :sequence_store_id, :upload_id, :source_file_type, :subject_id, :sample_id, :generated_from, :reference_arn, :name, :description, :tags, :creation_time) SENSITIVE = [] include Aws::Structure end |
#subject_id ⇒ String
The source's subject ID.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 |
# File 'lib/aws-sdk-omics/types.rb', line 1073 class CreateMultipartReadSetUploadResponse < Struct.new( :sequence_store_id, :upload_id, :source_file_type, :subject_id, :sample_id, :generated_from, :reference_arn, :name, :description, :tags, :creation_time) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to add to the read set.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 |
# File 'lib/aws-sdk-omics/types.rb', line 1073 class CreateMultipartReadSetUploadResponse < Struct.new( :sequence_store_id, :upload_id, :source_file_type, :subject_id, :sample_id, :generated_from, :reference_arn, :name, :description, :tags, :creation_time) SENSITIVE = [] include Aws::Structure end |
#upload_id ⇒ String
The ID for the initiated multipart upload.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 |
# File 'lib/aws-sdk-omics/types.rb', line 1073 class CreateMultipartReadSetUploadResponse < Struct.new( :sequence_store_id, :upload_id, :source_file_type, :subject_id, :sample_id, :generated_from, :reference_arn, :name, :description, :tags, :creation_time) SENSITIVE = [] include Aws::Structure end |