Method: Aws::Omics::Types::CreateSequenceStoreRequest#client_token
- Defined in:
- lib/aws-sdk-omics/types.rb
#client_token ⇒ String
An idempotency token used to dedupe retry requests so that duplicate runs are not created.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 |
# File 'lib/aws-sdk-omics/types.rb', line 1150 class CreateSequenceStoreRequest < Struct.new( :name, :description, :sse_config, :tags, :client_token, :fallback_location, :e_tag_algorithm_family, :propagated_set_level_tags, :s3_access_config) SENSITIVE = [] include Aws::Structure end |