Class: Aws::Omics::Types::CreateSequenceStoreResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::CreateSequenceStoreResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The store’s ARN.
-
#creation_time ⇒ Time
When the store was created.
-
#description ⇒ String
The store’s description.
-
#e_tag_algorithm_family ⇒ String
The algorithm family of the ETag.
-
#fallback_location ⇒ String
An S3 location that is used to store files that have failed a direct upload.
-
#id ⇒ String
The store’s ID.
-
#name ⇒ String
The store’s name.
-
#propagated_set_level_tags ⇒ Array<String>
The tags keys to propagate to the S3 objects associated with read sets in the sequence store.
-
#s3_access ⇒ Types::SequenceStoreS3Access
The S3 access metadata of the sequence store.
-
#sse_config ⇒ Types::SseConfig
Server-side encryption (SSE) settings for the store.
-
#status ⇒ String
The status of the sequence store.
-
#status_message ⇒ String
The status message of the sequence store.
Instance Attribute Details
#arn ⇒ String
The store’s ARN.
1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'lib/aws-sdk-omics/types.rb', line 1452 class CreateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :s3_access) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the store was created.
1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'lib/aws-sdk-omics/types.rb', line 1452 class CreateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :s3_access) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The store’s description.
1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'lib/aws-sdk-omics/types.rb', line 1452 class CreateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :s3_access) SENSITIVE = [] include Aws::Structure end |
#e_tag_algorithm_family ⇒ String
The algorithm family of the ETag.
1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'lib/aws-sdk-omics/types.rb', line 1452 class CreateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :s3_access) SENSITIVE = [] include Aws::Structure end |
#fallback_location ⇒ String
An S3 location that is used to store files that have failed a direct upload.
1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'lib/aws-sdk-omics/types.rb', line 1452 class CreateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :s3_access) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The store’s ID.
1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'lib/aws-sdk-omics/types.rb', line 1452 class CreateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :s3_access) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The store’s name.
1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'lib/aws-sdk-omics/types.rb', line 1452 class CreateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :s3_access) SENSITIVE = [] include Aws::Structure end |
#propagated_set_level_tags ⇒ Array<String>
The tags keys to propagate to the S3 objects associated with read sets in the sequence store.
1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'lib/aws-sdk-omics/types.rb', line 1452 class CreateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :s3_access) SENSITIVE = [] include Aws::Structure end |
#s3_access ⇒ Types::SequenceStoreS3Access
The S3 access metadata of the sequence store.
1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'lib/aws-sdk-omics/types.rb', line 1452 class CreateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :s3_access) SENSITIVE = [] include Aws::Structure end |
#sse_config ⇒ Types::SseConfig
Server-side encryption (SSE) settings for the store. This contains the KMS key ARN that is used to encrypt read set objects.
1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'lib/aws-sdk-omics/types.rb', line 1452 class CreateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :s3_access) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the sequence store.
1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'lib/aws-sdk-omics/types.rb', line 1452 class CreateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :s3_access) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The status message of the sequence store.
1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'lib/aws-sdk-omics/types.rb', line 1452 class CreateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :s3_access) SENSITIVE = [] include Aws::Structure end |