Class: Aws::Omics::Types::CreateWorkflowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::CreateWorkflowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accelerators ⇒ String
The computational accelerator specified to run the workflow.
-
#container_registry_map ⇒ Types::ContainerRegistryMap
(Optional) Use a container registry map to specify mappings between the ECR private repository and one or more upstream registries.
-
#container_registry_map_uri ⇒ String
(Optional) URI of the S3 location for the registry mapping file.
-
#definition_repository ⇒ Types::DefinitionRepository
The repository information for the workflow definition.
-
#definition_uri ⇒ String
The S3 URI of a definition for the workflow.
-
#definition_zip ⇒ String
A ZIP archive containing the main workflow definition file and dependencies that it imports for the workflow.
-
#description ⇒ String
A description for the workflow.
-
#engine ⇒ String
The workflow engine for the workflow.
-
#main ⇒ String
The path of the main definition file for the workflow.
-
#name ⇒ String
Name (optional but highly recommended) for the workflow to locate relevant information in the CloudWatch logs and Amazon Web Services HealthOmics console.
-
#parameter_template ⇒ Hash<String,Types::WorkflowParameter>
A parameter template for the workflow.
-
#parameter_template_path ⇒ String
The path to the workflow parameter template JSON file within the repository.
-
#readme_markdown ⇒ String
The markdown content for the workflow’s README file.
-
#readme_path ⇒ String
The path to the workflow README markdown file within the repository.
-
#readme_uri ⇒ String
The S3 URI of the README file for the workflow.
-
#request_id ⇒ String
An idempotency token to ensure that duplicate workflows are not created when Amazon Web Services HealthOmics submits retry requests.
-
#storage_capacity ⇒ Integer
The default static storage capacity (in gibibytes) for runs that use this workflow or workflow version.
-
#storage_type ⇒ String
The default storage type for runs that use this workflow.
-
#tags ⇒ Hash<String,String>
Tags for the workflow.
-
#workflow_bucket_owner_id ⇒ String
The Amazon Web Services account ID of the expected owner of the S3 bucket that contains the workflow definition.
Instance Attribute Details
#accelerators ⇒ String
The computational accelerator specified to run the workflow.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#container_registry_map ⇒ Types::ContainerRegistryMap
(Optional) Use a container registry map to specify mappings between the ECR private repository and one or more upstream registries. For more information, see [Container images] in the *Amazon Web Services HealthOmics User Guide*.
[1]: docs.aws.amazon.com/omics/latest/dev/workflows-ecr.html
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#container_registry_map_uri ⇒ String
(Optional) URI of the S3 location for the registry mapping file.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#definition_repository ⇒ Types::DefinitionRepository
The repository information for the workflow definition. This allows you to source your workflow definition directly from a code repository.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#definition_uri ⇒ String
The S3 URI of a definition for the workflow. The S3 bucket must be in the same region as the workflow.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#definition_zip ⇒ String
A ZIP archive containing the main workflow definition file and dependencies that it imports for the workflow. You can use a file with a ://fileb prefix instead of the Base64 string. For more information, see [Workflow definition requirements] in the *Amazon Web Services HealthOmics User Guide*.
[1]: docs.aws.amazon.com/omics/latest/dev/workflow-defn-requirements.html
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the workflow.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The workflow engine for the workflow. By default, Amazon Web Services HealthOmics detects the engine automatically from your workflow definition. Provide a value if you have workflow definition files from more than one engine in your zip file, or to use WDL lenient.
WDL lenient is designed to handle workflows migrated from Cromwell. It supports customer Cromwell directives and some non-conformant logic. For details, see [Implicit type conversion in WDL lenient] in the *Amazon Web Services HealthOmics User Guide*.
[1]: docs.aws.amazon.com/omics/latest/dev/workflow-wdl-type-conversion.html
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#main ⇒ String
The path of the main definition file for the workflow. This parameter is not required if the ZIP archive contains only one workflow definition file, or if the main definition file is named “main”. An example path is: ‘workflow-definition/main-file.wdl`.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name (optional but highly recommended) for the workflow to locate relevant information in the CloudWatch logs and Amazon Web Services HealthOmics console.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#parameter_template ⇒ Hash<String,Types::WorkflowParameter>
A parameter template for the workflow. If this field is blank, Amazon Web Services HealthOmics will automatically parse the parameter template values from your workflow definition file. To override these service generated default values, provide a parameter template. To view an example of a parameter template, see [Parameter template files] in the *Amazon Web Services HealthOmics User Guide*.
[1]: docs.aws.amazon.com/omics/latest/dev/parameter-templates.html
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#parameter_template_path ⇒ String
The path to the workflow parameter template JSON file within the repository. This file defines the input parameters for runs that use this workflow. If not specified, the workflow will be created without a parameter template.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#readme_markdown ⇒ String
The markdown content for the workflow’s README file. This provides documentation and usage information for users of the workflow.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#readme_path ⇒ String
The path to the workflow README markdown file within the repository. This file provides documentation and usage information for the workflow. If not specified, the ‘README.md` file from the root directory of the repository will be used.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#readme_uri ⇒ String
The S3 URI of the README file for the workflow. This file provides documentation and usage information for the workflow. Requirements include:
-
The S3 URI must begin with ‘s3://USER-OWNED-BUCKET/`
-
The requester must have access to the S3 bucket and object.
-
The max README content length is 500 KiB.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
An idempotency token to ensure that duplicate workflows are not created when Amazon Web Services HealthOmics submits retry requests.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#storage_capacity ⇒ Integer
The default static storage capacity (in gibibytes) for runs that use this workflow or workflow version. The ‘storageCapacity` can be overwritten at run time. The storage capacity is not required for runs with a `DYNAMIC` storage type.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
The default storage type for runs that use this workflow. The ‘storageType` can be overridden at run time. `DYNAMIC` storage dynamically scales the storage up or down, based on file system utilization. `STATIC` storage allocates a fixed amount of storage. For more information about dynamic and static storage types, see
- Run storage types][1
-
in the *Amazon Web Services HealthOmics User
Guide*.
[1]: docs.aws.amazon.com/omics/latest/dev/workflows-run-types.html
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags for the workflow. You can define up to 50 tags for the workflow. For more information, see [Adding a tag] in the *Amazon Web Services HealthOmics User Guide*.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |
#workflow_bucket_owner_id ⇒ String
The Amazon Web Services account ID of the expected owner of the S3 bucket that contains the workflow definition. If not specified, the service skips the validation.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 |
# File 'lib/aws-sdk-omics/types.rb', line 1746 class CreateWorkflowRequest < Struct.new( :name, :description, :engine, :definition_zip, :definition_uri, :main, :parameter_template, :storage_capacity, :tags, :request_id, :accelerators, :storage_type, :container_registry_map, :container_registry_map_uri, :readme_markdown, :parameter_template_path, :readme_path, :definition_repository, :workflow_bucket_owner_id, :readme_uri) SENSITIVE = [] include Aws::Structure end |