Class: Aws::Omics::Types::DeleteAnnotationStoreVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::DeleteAnnotationStoreVersionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#force ⇒ Boolean
Forces the deletion of an annotation store version when imports are in-progress..
-
#name ⇒ String
The name of the annotation store from which versions are being deleted.
-
#versions ⇒ Array<String>
The versions of an annotation store to be deleted.
Instance Attribute Details
#force ⇒ Boolean
Forces the deletion of an annotation store version when imports are in-progress..
2282 2283 2284 2285 2286 2287 2288 |
# File 'lib/aws-sdk-omics/types.rb', line 2282 class DeleteAnnotationStoreVersionsRequest < Struct.new( :name, :versions, :force) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the annotation store from which versions are being deleted.
2282 2283 2284 2285 2286 2287 2288 |
# File 'lib/aws-sdk-omics/types.rb', line 2282 class DeleteAnnotationStoreVersionsRequest < Struct.new( :name, :versions, :force) SENSITIVE = [] include Aws::Structure end |
#versions ⇒ Array<String>
The versions of an annotation store to be deleted.
2282 2283 2284 2285 2286 2287 2288 |
# File 'lib/aws-sdk-omics/types.rb', line 2282 class DeleteAnnotationStoreVersionsRequest < Struct.new( :name, :versions, :force) SENSITIVE = [] include Aws::Structure end |