Class: Aws::Omics::Types::GetAnnotationStoreResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::GetAnnotationStoreResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
When the store was created.
-
#description ⇒ String
The store's description.
-
#id ⇒ String
The store's ID.
-
#name ⇒ String
The store's name.
-
#num_versions ⇒ Integer
An integer indicating how many versions of an annotation store exist.
-
#reference ⇒ Types::ReferenceItem
The store's genome reference.
-
#sse_config ⇒ Types::SseConfig
The store's server-side encryption (SSE) settings.
-
#status ⇒ String
The store's status.
-
#status_message ⇒ String
A status message.
-
#store_arn ⇒ String
The store's ARN.
-
#store_format ⇒ String
The store's annotation file format.
-
#store_options ⇒ Types::StoreOptions
The store's parsing options.
-
#store_size_bytes ⇒ Integer
The store's size in bytes.
-
#tags ⇒ Hash<String,String>
The store's tags.
-
#update_time ⇒ Time
When the store was updated.
Instance Attribute Details
#creation_time ⇒ Time
When the store was created.
2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/aws-sdk-omics/types.rb', line 2923 class GetAnnotationStoreResponse < Struct.new( :id, :reference, :status, :store_arn, :name, :description, :sse_config, :creation_time, :update_time, :tags, :store_options, :store_format, :status_message, :store_size_bytes, :num_versions) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The store's description.
2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/aws-sdk-omics/types.rb', line 2923 class GetAnnotationStoreResponse < Struct.new( :id, :reference, :status, :store_arn, :name, :description, :sse_config, :creation_time, :update_time, :tags, :store_options, :store_format, :status_message, :store_size_bytes, :num_versions) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The store's ID.
2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/aws-sdk-omics/types.rb', line 2923 class GetAnnotationStoreResponse < Struct.new( :id, :reference, :status, :store_arn, :name, :description, :sse_config, :creation_time, :update_time, :tags, :store_options, :store_format, :status_message, :store_size_bytes, :num_versions) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The store's name.
2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/aws-sdk-omics/types.rb', line 2923 class GetAnnotationStoreResponse < Struct.new( :id, :reference, :status, :store_arn, :name, :description, :sse_config, :creation_time, :update_time, :tags, :store_options, :store_format, :status_message, :store_size_bytes, :num_versions) SENSITIVE = [] include Aws::Structure end |
#num_versions ⇒ Integer
An integer indicating how many versions of an annotation store exist.
2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/aws-sdk-omics/types.rb', line 2923 class GetAnnotationStoreResponse < Struct.new( :id, :reference, :status, :store_arn, :name, :description, :sse_config, :creation_time, :update_time, :tags, :store_options, :store_format, :status_message, :store_size_bytes, :num_versions) SENSITIVE = [] include Aws::Structure end |
#reference ⇒ Types::ReferenceItem
The store's genome reference.
2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/aws-sdk-omics/types.rb', line 2923 class GetAnnotationStoreResponse < Struct.new( :id, :reference, :status, :store_arn, :name, :description, :sse_config, :creation_time, :update_time, :tags, :store_options, :store_format, :status_message, :store_size_bytes, :num_versions) SENSITIVE = [] include Aws::Structure end |
#sse_config ⇒ Types::SseConfig
The store's server-side encryption (SSE) settings.
2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/aws-sdk-omics/types.rb', line 2923 class GetAnnotationStoreResponse < Struct.new( :id, :reference, :status, :store_arn, :name, :description, :sse_config, :creation_time, :update_time, :tags, :store_options, :store_format, :status_message, :store_size_bytes, :num_versions) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The store's status.
2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/aws-sdk-omics/types.rb', line 2923 class GetAnnotationStoreResponse < Struct.new( :id, :reference, :status, :store_arn, :name, :description, :sse_config, :creation_time, :update_time, :tags, :store_options, :store_format, :status_message, :store_size_bytes, :num_versions) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A status message.
2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/aws-sdk-omics/types.rb', line 2923 class GetAnnotationStoreResponse < Struct.new( :id, :reference, :status, :store_arn, :name, :description, :sse_config, :creation_time, :update_time, :tags, :store_options, :store_format, :status_message, :store_size_bytes, :num_versions) SENSITIVE = [] include Aws::Structure end |
#store_arn ⇒ String
The store's ARN.
2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/aws-sdk-omics/types.rb', line 2923 class GetAnnotationStoreResponse < Struct.new( :id, :reference, :status, :store_arn, :name, :description, :sse_config, :creation_time, :update_time, :tags, :store_options, :store_format, :status_message, :store_size_bytes, :num_versions) SENSITIVE = [] include Aws::Structure end |
#store_format ⇒ String
The store's annotation file format.
2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/aws-sdk-omics/types.rb', line 2923 class GetAnnotationStoreResponse < Struct.new( :id, :reference, :status, :store_arn, :name, :description, :sse_config, :creation_time, :update_time, :tags, :store_options, :store_format, :status_message, :store_size_bytes, :num_versions) SENSITIVE = [] include Aws::Structure end |
#store_options ⇒ Types::StoreOptions
The store's parsing options.
2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/aws-sdk-omics/types.rb', line 2923 class GetAnnotationStoreResponse < Struct.new( :id, :reference, :status, :store_arn, :name, :description, :sse_config, :creation_time, :update_time, :tags, :store_options, :store_format, :status_message, :store_size_bytes, :num_versions) SENSITIVE = [] include Aws::Structure end |
#store_size_bytes ⇒ Integer
The store's size in bytes.
2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/aws-sdk-omics/types.rb', line 2923 class GetAnnotationStoreResponse < Struct.new( :id, :reference, :status, :store_arn, :name, :description, :sse_config, :creation_time, :update_time, :tags, :store_options, :store_format, :status_message, :store_size_bytes, :num_versions) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The store's tags.
2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/aws-sdk-omics/types.rb', line 2923 class GetAnnotationStoreResponse < Struct.new( :id, :reference, :status, :store_arn, :name, :description, :sse_config, :creation_time, :update_time, :tags, :store_options, :store_format, :status_message, :store_size_bytes, :num_versions) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
When the store was updated.
2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/aws-sdk-omics/types.rb', line 2923 class GetAnnotationStoreResponse < Struct.new( :id, :reference, :status, :store_arn, :name, :description, :sse_config, :creation_time, :update_time, :tags, :store_options, :store_format, :status_message, :store_size_bytes, :num_versions) SENSITIVE = [] include Aws::Structure end |