Class: Aws::Omics::Types::GetAnnotationStoreVersionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::GetAnnotationStoreVersionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The time stamp for when an annotation store version was created.
-
#description ⇒ String
The description for an annotation store version.
-
#id ⇒ String
The annotation store version ID.
-
#name ⇒ String
The name of the annotation store.
-
#status ⇒ String
The status of an annotation store version.
-
#status_message ⇒ String
The status of an annotation store version.
-
#store_id ⇒ String
The store ID for annotation store version.
-
#tags ⇒ Hash<String,String>
Any tags associated with an annotation store version.
-
#update_time ⇒ Time
The time stamp for when an annotation store version was updated.
-
#version_arn ⇒ String
The Arn for the annotation store.
-
#version_name ⇒ String
The name given to an annotation store version to distinguish it from others.
-
#version_options ⇒ Types::VersionOptions
The options for an annotation store version.
-
#version_size_bytes ⇒ Integer
The size of the annotation store version in Bytes.
Instance Attribute Details
#creation_time ⇒ Time
The time stamp for when an annotation store version was created.
3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-omics/types.rb', line 3002 class GetAnnotationStoreVersionResponse < Struct.new( :store_id, :id, :status, :version_arn, :name, :version_name, :description, :creation_time, :update_time, :tags, :version_options, :status_message, :version_size_bytes) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for an annotation store version.
3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-omics/types.rb', line 3002 class GetAnnotationStoreVersionResponse < Struct.new( :store_id, :id, :status, :version_arn, :name, :version_name, :description, :creation_time, :update_time, :tags, :version_options, :status_message, :version_size_bytes) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The annotation store version ID.
3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-omics/types.rb', line 3002 class GetAnnotationStoreVersionResponse < Struct.new( :store_id, :id, :status, :version_arn, :name, :version_name, :description, :creation_time, :update_time, :tags, :version_options, :status_message, :version_size_bytes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the annotation store.
3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-omics/types.rb', line 3002 class GetAnnotationStoreVersionResponse < Struct.new( :store_id, :id, :status, :version_arn, :name, :version_name, :description, :creation_time, :update_time, :tags, :version_options, :status_message, :version_size_bytes) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of an annotation store version.
3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-omics/types.rb', line 3002 class GetAnnotationStoreVersionResponse < Struct.new( :store_id, :id, :status, :version_arn, :name, :version_name, :description, :creation_time, :update_time, :tags, :version_options, :status_message, :version_size_bytes) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The status of an annotation store version.
3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-omics/types.rb', line 3002 class GetAnnotationStoreVersionResponse < Struct.new( :store_id, :id, :status, :version_arn, :name, :version_name, :description, :creation_time, :update_time, :tags, :version_options, :status_message, :version_size_bytes) SENSITIVE = [] include Aws::Structure end |
#store_id ⇒ String
The store ID for annotation store version.
3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-omics/types.rb', line 3002 class GetAnnotationStoreVersionResponse < Struct.new( :store_id, :id, :status, :version_arn, :name, :version_name, :description, :creation_time, :update_time, :tags, :version_options, :status_message, :version_size_bytes) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Any tags associated with an annotation store version.
3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-omics/types.rb', line 3002 class GetAnnotationStoreVersionResponse < Struct.new( :store_id, :id, :status, :version_arn, :name, :version_name, :description, :creation_time, :update_time, :tags, :version_options, :status_message, :version_size_bytes) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time stamp for when an annotation store version was updated.
3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-omics/types.rb', line 3002 class GetAnnotationStoreVersionResponse < Struct.new( :store_id, :id, :status, :version_arn, :name, :version_name, :description, :creation_time, :update_time, :tags, :version_options, :status_message, :version_size_bytes) SENSITIVE = [] include Aws::Structure end |
#version_arn ⇒ String
The Arn for the annotation store.
3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-omics/types.rb', line 3002 class GetAnnotationStoreVersionResponse < Struct.new( :store_id, :id, :status, :version_arn, :name, :version_name, :description, :creation_time, :update_time, :tags, :version_options, :status_message, :version_size_bytes) SENSITIVE = [] include Aws::Structure end |
#version_name ⇒ String
The name given to an annotation store version to distinguish it from others.
3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-omics/types.rb', line 3002 class GetAnnotationStoreVersionResponse < Struct.new( :store_id, :id, :status, :version_arn, :name, :version_name, :description, :creation_time, :update_time, :tags, :version_options, :status_message, :version_size_bytes) SENSITIVE = [] include Aws::Structure end |
#version_options ⇒ Types::VersionOptions
The options for an annotation store version.
3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-omics/types.rb', line 3002 class GetAnnotationStoreVersionResponse < Struct.new( :store_id, :id, :status, :version_arn, :name, :version_name, :description, :creation_time, :update_time, :tags, :version_options, :status_message, :version_size_bytes) SENSITIVE = [] include Aws::Structure end |
#version_size_bytes ⇒ Integer
The size of the annotation store version in Bytes.
3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-omics/types.rb', line 3002 class GetAnnotationStoreVersionResponse < Struct.new( :store_id, :id, :status, :version_arn, :name, :version_name, :description, :creation_time, :update_time, :tags, :version_options, :status_message, :version_size_bytes) SENSITIVE = [] include Aws::Structure end |