Class: Aws::Omics::Types::GetBatchResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-omics/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The unique ARN of the run batch.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
# File 'lib/aws-sdk-omics/types.rb', line 3081

class GetBatchResponse < Struct.new(
  :id,
  :arn,
  :uuid,
  :name,
  :status,
  :tags,
  :total_runs,
  :default_run_setting,
  :submission_summary,
  :run_summary,
  :creation_time,
  :submitted_time,
  :processed_time,
  :failed_time,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The timestamp when the batch was created.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
# File 'lib/aws-sdk-omics/types.rb', line 3081

class GetBatchResponse < Struct.new(
  :id,
  :arn,
  :uuid,
  :name,
  :status,
  :tags,
  :total_runs,
  :default_run_setting,
  :submission_summary,
  :run_summary,
  :creation_time,
  :submitted_time,
  :processed_time,
  :failed_time,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#default_run_settingTypes::DefaultRunSetting

The shared configuration applied to all runs in the batch. See DefaultRunSetting.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
# File 'lib/aws-sdk-omics/types.rb', line 3081

class GetBatchResponse < Struct.new(
  :id,
  :arn,
  :uuid,
  :name,
  :status,
  :tags,
  :total_runs,
  :default_run_setting,
  :submission_summary,
  :run_summary,
  :creation_time,
  :submitted_time,
  :processed_time,
  :failed_time,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#failed_timeTime

The timestamp when the batch transitioned to a FAILED status.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
# File 'lib/aws-sdk-omics/types.rb', line 3081

class GetBatchResponse < Struct.new(
  :id,
  :arn,
  :uuid,
  :name,
  :status,
  :tags,
  :total_runs,
  :default_run_setting,
  :submission_summary,
  :run_summary,
  :creation_time,
  :submitted_time,
  :processed_time,
  :failed_time,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

A description of the batch failure. Present only when status is FAILED.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
# File 'lib/aws-sdk-omics/types.rb', line 3081

class GetBatchResponse < Struct.new(
  :id,
  :arn,
  :uuid,
  :name,
  :status,
  :tags,
  :total_runs,
  :default_run_setting,
  :submission_summary,
  :run_summary,
  :creation_time,
  :submitted_time,
  :processed_time,
  :failed_time,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier portion of the run batch ARN.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
# File 'lib/aws-sdk-omics/types.rb', line 3081

class GetBatchResponse < Struct.new(
  :id,
  :arn,
  :uuid,
  :name,
  :status,
  :tags,
  :total_runs,
  :default_run_setting,
  :submission_summary,
  :run_summary,
  :creation_time,
  :submitted_time,
  :processed_time,
  :failed_time,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The optional user-friendly name of the batch.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
# File 'lib/aws-sdk-omics/types.rb', line 3081

class GetBatchResponse < Struct.new(
  :id,
  :arn,
  :uuid,
  :name,
  :status,
  :tags,
  :total_runs,
  :default_run_setting,
  :submission_summary,
  :run_summary,
  :creation_time,
  :submitted_time,
  :processed_time,
  :failed_time,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#processed_timeTime

The timestamp when all run executions completed.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
# File 'lib/aws-sdk-omics/types.rb', line 3081

class GetBatchResponse < Struct.new(
  :id,
  :arn,
  :uuid,
  :name,
  :status,
  :tags,
  :total_runs,
  :default_run_setting,
  :submission_summary,
  :run_summary,
  :creation_time,
  :submitted_time,
  :processed_time,
  :failed_time,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#run_summaryTypes::RunSummary

A summary of run execution states. Run execution counts are eventually consistent and may lag behind actual run states. Final counts are accurate once the batch reaches PROCESSED status. See RunSummary.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
# File 'lib/aws-sdk-omics/types.rb', line 3081

class GetBatchResponse < Struct.new(
  :id,
  :arn,
  :uuid,
  :name,
  :status,
  :tags,
  :total_runs,
  :default_run_setting,
  :submission_summary,
  :run_summary,
  :creation_time,
  :submitted_time,
  :processed_time,
  :failed_time,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the run batch.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
# File 'lib/aws-sdk-omics/types.rb', line 3081

class GetBatchResponse < Struct.new(
  :id,
  :arn,
  :uuid,
  :name,
  :status,
  :tags,
  :total_runs,
  :default_run_setting,
  :submission_summary,
  :run_summary,
  :creation_time,
  :submitted_time,
  :processed_time,
  :failed_time,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#submission_summaryTypes::SubmissionSummary

A summary of run submission outcomes. See SubmissionSummary.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
# File 'lib/aws-sdk-omics/types.rb', line 3081

class GetBatchResponse < Struct.new(
  :id,
  :arn,
  :uuid,
  :name,
  :status,
  :tags,
  :total_runs,
  :default_run_setting,
  :submission_summary,
  :run_summary,
  :creation_time,
  :submitted_time,
  :processed_time,
  :failed_time,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#submitted_timeTime

The timestamp when all run submissions completed.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
# File 'lib/aws-sdk-omics/types.rb', line 3081

class GetBatchResponse < Struct.new(
  :id,
  :arn,
  :uuid,
  :name,
  :status,
  :tags,
  :total_runs,
  :default_run_setting,
  :submission_summary,
  :run_summary,
  :creation_time,
  :submitted_time,
  :processed_time,
  :failed_time,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

AWS tags associated with the run batch.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
# File 'lib/aws-sdk-omics/types.rb', line 3081

class GetBatchResponse < Struct.new(
  :id,
  :arn,
  :uuid,
  :name,
  :status,
  :tags,
  :total_runs,
  :default_run_setting,
  :submission_summary,
  :run_summary,
  :creation_time,
  :submitted_time,
  :processed_time,
  :failed_time,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#total_runsInteger

The total number of runs in the batch.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
# File 'lib/aws-sdk-omics/types.rb', line 3081

class GetBatchResponse < Struct.new(
  :id,
  :arn,
  :uuid,
  :name,
  :status,
  :tags,
  :total_runs,
  :default_run_setting,
  :submission_summary,
  :run_summary,
  :creation_time,
  :submitted_time,
  :processed_time,
  :failed_time,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#uuidString

The universally unique identifier (UUID) for the run batch.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
# File 'lib/aws-sdk-omics/types.rb', line 3081

class GetBatchResponse < Struct.new(
  :id,
  :arn,
  :uuid,
  :name,
  :status,
  :tags,
  :total_runs,
  :default_run_setting,
  :submission_summary,
  :run_summary,
  :creation_time,
  :submitted_time,
  :processed_time,
  :failed_time,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end