Class: Aws::Omics::Types::GetReadSetMetadataResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::GetReadSetMetadataResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The read set’s ARN.
-
#creation_job_id ⇒ String
The read set’s creation job ID.
-
#creation_time ⇒ Time
When the read set was created.
-
#creation_type ⇒ String
The creation type of the read set.
-
#description ⇒ String
The read set’s description.
-
#etag ⇒ Types::ETag
The entity tag (ETag) is a hash of the object meant to represent its semantic content.
-
#file_type ⇒ String
The read set’s file type.
-
#files ⇒ Types::ReadSetFiles
The read set’s files.
-
#id ⇒ String
The read set’s ID.
-
#name ⇒ String
The read set’s name.
-
#reference_arn ⇒ String
The read set’s genome reference ARN.
-
#sample_id ⇒ String
The read set’s sample ID.
-
#sequence_information ⇒ Types::SequenceInformation
The read set’s sequence information.
-
#sequence_store_id ⇒ String
The read set’s sequence store ID.
-
#status ⇒ String
The read set’s status.
-
#status_message ⇒ String
The status message for a read set.
-
#subject_id ⇒ String
The read set’s subject ID.
Instance Attribute Details
#arn ⇒ String
The read set’s ARN.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#creation_job_id ⇒ String
The read set’s creation job ID.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the read set was created.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#creation_type ⇒ String
The creation type of the read set.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The read set’s description.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ Types::ETag
The entity tag (ETag) is a hash of the object meant to represent its semantic content.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#file_type ⇒ String
The read set’s file type.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#files ⇒ Types::ReadSetFiles
The read set’s files.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The read set’s ID.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The read set’s name.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#reference_arn ⇒ String
The read set’s genome reference ARN.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#sample_id ⇒ String
The read set’s sample ID.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#sequence_information ⇒ Types::SequenceInformation
The read set’s sequence information.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#sequence_store_id ⇒ String
The read set’s sequence store ID.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The read set’s status.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The status message for a read set. It provides more detail as to why the read set has a status.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |
#subject_id ⇒ String
The read set’s subject ID.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/aws-sdk-omics/types.rb', line 3452 class GetReadSetMetadataResponse < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :file_type, :creation_time, :sequence_information, :reference_arn, :files, :status_message, :creation_type, :etag, :creation_job_id) SENSITIVE = [] include Aws::Structure end |