Class: Aws::Omics::Types::GetRunGroupResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-omics/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The group’s ARN.



3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
# File 'lib/aws-sdk-omics/types.rb', line 3857

class GetRunGroupResponse < Struct.new(
  :arn,
  :id,
  :name,
  :max_cpus,
  :max_runs,
  :max_duration,
  :creation_time,
  :tags,
  :max_gpus)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

When the group was created.



3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
# File 'lib/aws-sdk-omics/types.rb', line 3857

class GetRunGroupResponse < Struct.new(
  :arn,
  :id,
  :name,
  :max_cpus,
  :max_runs,
  :max_duration,
  :creation_time,
  :tags,
  :max_gpus)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The group’s ID.



3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
# File 'lib/aws-sdk-omics/types.rb', line 3857

class GetRunGroupResponse < Struct.new(
  :arn,
  :id,
  :name,
  :max_cpus,
  :max_runs,
  :max_duration,
  :creation_time,
  :tags,
  :max_gpus)
  SENSITIVE = []
  include Aws::Structure
end

#max_cpusInteger

The group’s maximum number of CPUs to use.



3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
# File 'lib/aws-sdk-omics/types.rb', line 3857

class GetRunGroupResponse < Struct.new(
  :arn,
  :id,
  :name,
  :max_cpus,
  :max_runs,
  :max_duration,
  :creation_time,
  :tags,
  :max_gpus)
  SENSITIVE = []
  include Aws::Structure
end

#max_durationInteger

The group’s maximum run time in minutes.



3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
# File 'lib/aws-sdk-omics/types.rb', line 3857

class GetRunGroupResponse < Struct.new(
  :arn,
  :id,
  :name,
  :max_cpus,
  :max_runs,
  :max_duration,
  :creation_time,
  :tags,
  :max_gpus)
  SENSITIVE = []
  include Aws::Structure
end

#max_gpusInteger

The maximum GPUs that can be used by a run group.



3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
# File 'lib/aws-sdk-omics/types.rb', line 3857

class GetRunGroupResponse < Struct.new(
  :arn,
  :id,
  :name,
  :max_cpus,
  :max_runs,
  :max_duration,
  :creation_time,
  :tags,
  :max_gpus)
  SENSITIVE = []
  include Aws::Structure
end

#max_runsInteger

The maximum number of concurrent runs for the group.



3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
# File 'lib/aws-sdk-omics/types.rb', line 3857

class GetRunGroupResponse < Struct.new(
  :arn,
  :id,
  :name,
  :max_cpus,
  :max_runs,
  :max_duration,
  :creation_time,
  :tags,
  :max_gpus)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The group’s name.



3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
# File 'lib/aws-sdk-omics/types.rb', line 3857

class GetRunGroupResponse < Struct.new(
  :arn,
  :id,
  :name,
  :max_cpus,
  :max_runs,
  :max_duration,
  :creation_time,
  :tags,
  :max_gpus)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The group’s tags.



3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
# File 'lib/aws-sdk-omics/types.rb', line 3857

class GetRunGroupResponse < Struct.new(
  :arn,
  :id,
  :name,
  :max_cpus,
  :max_runs,
  :max_duration,
  :creation_time,
  :tags,
  :max_gpus)
  SENSITIVE = []
  include Aws::Structure
end