Class: Aws::Omics::Types::GetRunResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-omics/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acceleratorsString

The computational accelerator used to run the workflow.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The run’s ARN.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#batch_idString

The run’s batch ID.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#cache_behaviorString

The run cache behavior for the run.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#cache_idString

The run cache associated with the run.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#configurationTypes::ConfigurationDetails

Configuration details for the workflow run.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

When the run was created.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#definitionString

The run’s definition.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#digestString

The run’s digest.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The actual Nextflow engine version that Amazon Web Services HealthOmics used for the run. The other workflow definition languages don’t provide a value for this field.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

The reason a run has failed.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The run’s ID.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

The run’s log level.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#log_locationTypes::RunLogLocation

The location of the run log.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The run’s name.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#networking_modeString

Configuration for run networking behavior. If absent, this will default to RESTRICTED.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#output_uriString

The run’s output URI.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash, ...

The run’s parameters.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#priorityInteger

The run’s priority.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#resource_digestsHash<String,String>

The run’s resource digests.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#retention_modeString

The run’s retention mode.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The run’s service role ARN.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#run_group_idString

The run’s group ID.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#run_idString

The run’s ID.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#run_output_uriString

The destination for workflow outputs.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

When the run started.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#started_byString

Who started the run.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The run’s status.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

The run’s status message.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#stop_timeTime

The run’s stop time.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#storage_capacityInteger

The run’s storage capacity in gibibytes. For dynamic storage, after the run has completed, this value is the maximum amount of storage used during the run.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The run’s storage type.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The run’s tags.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#uuidString

The universally unique identifier for a run.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfigResponse

VPC configuration for the workflow run.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_idString

The run’s workflow ID.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_owner_idString

The ID of the workflow owner.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_typeString

The run’s workflow type.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_uuidString

The universally unique identifier (UUID) value for the workflow.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_version_nameString

The workflow version name.

Returns:



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/aws-sdk-omics/types.rb', line 4055

class GetRunResponse < Struct.new(
  :arn,
  :id,
  :cache_id,
  :cache_behavior,
  :engine_version,
  :status,
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :run_group_id,
  :batch_id,
  :priority,
  :definition,
  :digest,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :resource_digests,
  :started_by,
  :creation_time,
  :start_time,
  :stop_time,
  :status_message,
  :tags,
  :accelerators,
  :retention_mode,
  :failure_reason,
  :log_location,
  :uuid,
  :run_output_uri,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :workflow_uuid,
  :networking_mode,
  :configuration,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end