Class: Aws::Omics::Types::GetRunTaskResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::GetRunTaskResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_hit ⇒ Boolean
Set to true if Amazon Web Services HealthOmics found a matching entry in the run cache for this task.
-
#cache_s3_uri ⇒ String
The S3 URI of the cache location.
-
#cpus ⇒ Integer
The task’s CPU usage.
-
#creation_time ⇒ Time
When the task was created.
-
#failure_reason ⇒ String
The reason a task has failed.
-
#gpus ⇒ Integer
The number of Graphics Processing Units (GPU) specified in the task.
-
#image_details ⇒ Types::ImageDetails
Details about the container image that this task uses.
-
#instance_type ⇒ String
The instance type for a task.
-
#log_stream ⇒ String
The task’s log stream.
-
#memory ⇒ Integer
The task’s memory use in gigabytes.
-
#name ⇒ String
The task’s name.
-
#start_time ⇒ Time
The task’s start time.
-
#status ⇒ String
The task’s status.
-
#status_message ⇒ String
The task’s status message.
-
#stop_time ⇒ Time
The task’s stop time.
-
#task_id ⇒ String
The task’s ID.
Instance Attribute Details
#cache_hit ⇒ Boolean
Set to true if Amazon Web Services HealthOmics found a matching entry in the run cache for this task.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |
#cache_s3_uri ⇒ String
The S3 URI of the cache location.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |
#cpus ⇒ Integer
The task’s CPU usage.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the task was created.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reason a task has failed.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |
#gpus ⇒ Integer
The number of Graphics Processing Units (GPU) specified in the task.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |
#image_details ⇒ Types::ImageDetails
Details about the container image that this task uses.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type for a task.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |
#log_stream ⇒ String
The task’s log stream.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |
#memory ⇒ Integer
The task’s memory use in gigabytes.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The task’s name.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The task’s start time.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The task’s status.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The task’s status message.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |
#stop_time ⇒ Time
The task’s stop time.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The task’s ID.
4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/aws-sdk-omics/types.rb', line 4228 class GetRunTaskResponse < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :status_message, :log_stream, :gpus, :instance_type, :failure_reason, :image_details) SENSITIVE = [] include Aws::Structure end |