Class: Aws::Omics::Types::GetWorkflowResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::GetWorkflowResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accelerators ⇒ String
The computational accelerator specified to run the workflow.
-
#arn ⇒ String
The workflow's ARN.
-
#container_registry_map ⇒ Types::ContainerRegistryMap
The registry map that this workflow is using.
-
#creation_time ⇒ Time
When the workflow was created.
-
#definition ⇒ String
The workflow's definition.
-
#definition_repository_details ⇒ Types::DefinitionRepositoryDetails
Details about the source code repository that hosts the workflow definition files.
-
#description ⇒ String
The workflow's description.
-
#digest ⇒ String
The workflow's digest.
-
#engine ⇒ String
The workflow's engine.
-
#id ⇒ String
The workflow's ID.
-
#main ⇒ String
The path of the main definition file for the workflow.
-
#metadata ⇒ Hash<String,String>
Gets metadata for the workflow.
-
#name ⇒ String
The workflow's name.
-
#parameter_template ⇒ Hash<String,Types::WorkflowParameter>
The workflow's parameter template.
-
#profile_parameter_templates ⇒ Hash<String,Hash<String,Types::WorkflowParameter>>
A mapping of profile names to their parameter templates.
-
#profiles ⇒ Array<String>
The list of Nextflow profiles that are available for this workflow.
-
#readme ⇒ String
The README content for the workflow, providing documentation and usage information.
-
#readme_path ⇒ String
The path to the workflow README markdown file within the repository.
-
#status ⇒ String
The workflow's status.
-
#status_message ⇒ String
The workflow's status message.
-
#storage_capacity ⇒ Integer
The default static storage capacity (in gibibytes) for runs that use this workflow or workflow version.
-
#storage_type ⇒ String
The default storage type for runs using this workflow.
-
#tags ⇒ Hash<String,String>
The workflow's tags.
-
#type ⇒ String
The workflow's type.
-
#uuid ⇒ String
The universally unique identifier (UUID) value for this workflow.
Instance Attribute Details
#accelerators ⇒ String
The computational accelerator specified to run the workflow.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The workflow's ARN.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#container_registry_map ⇒ Types::ContainerRegistryMap
The registry map that this workflow is using.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the workflow was created.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#definition ⇒ String
The workflow's definition.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#definition_repository_details ⇒ Types::DefinitionRepositoryDetails
Details about the source code repository that hosts the workflow definition files.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The workflow's description.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#digest ⇒ String
The workflow's digest.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The workflow's engine.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The workflow's ID.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#main ⇒ String
The path of the main definition file for the workflow.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Hash<String,String>
Gets metadata for the workflow.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The workflow's name.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#parameter_template ⇒ Hash<String,Types::WorkflowParameter>
The workflow's parameter template.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#profile_parameter_templates ⇒ Hash<String,Hash<String,Types::WorkflowParameter>>
A mapping of profile names to their parameter templates. Each profile defines its own set of parameters that you can use when starting a run with that profile.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#profiles ⇒ Array<String>
The list of Nextflow profiles that are available for this workflow. Profiles allow you to select predefined configuration settings at runtime.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#readme ⇒ String
The README content for the workflow, providing documentation and usage information.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#readme_path ⇒ String
The path to the workflow README markdown file within the repository.
This file provides documentation and usage information for the
workflow. If not specified, the README.md file from the root
directory of the repository will be used.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The workflow's status.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The workflow's status message.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#storage_capacity ⇒ Integer
The default static storage capacity (in gibibytes) for runs that use this workflow or workflow version.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
The default storage type for runs using this workflow.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The workflow's tags.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The workflow's type.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#uuid ⇒ String
The universally unique identifier (UUID) value for this workflow.
4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 |
# File 'lib/aws-sdk-omics/types.rb', line 4717 class GetWorkflowResponse < Struct.new( :arn, :id, :status, :type, :name, :description, :engine, :definition, :main, :digest, :parameter_template, :storage_capacity, :creation_time, :status_message, :tags, :metadata, :accelerators, :storage_type, :uuid, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |