Class: Aws::Omics::Types::ImageDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::ImageDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Information about the container image used for a task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image ⇒ String
The URI of the container image.
-
#image_digest ⇒ String
The container image digest.
-
#source_image ⇒ String
URI of the source registry.
Instance Attribute Details
#image ⇒ String
The URI of the container image.
4929 4930 4931 4932 4933 4934 4935 |
# File 'lib/aws-sdk-omics/types.rb', line 4929 class ImageDetails < Struct.new( :image, :image_digest, :source_image) SENSITIVE = [] include Aws::Structure end |
#image_digest ⇒ String
The container image digest. If the image URI was transformed, this will be the digest of the container image referenced by the transformed URI.
4929 4930 4931 4932 4933 4934 4935 |
# File 'lib/aws-sdk-omics/types.rb', line 4929 class ImageDetails < Struct.new( :image, :image_digest, :source_image) SENSITIVE = [] include Aws::Structure end |
#source_image ⇒ String
URI of the source registry. If the URI is from a third-party registry, Amazon Web Services HealthOmics transforms the URI to the corresponding ECR path, using the pull-through cache mapping rules.
4929 4930 4931 4932 4933 4934 4935 |
# File 'lib/aws-sdk-omics/types.rb', line 4929 class ImageDetails < Struct.new( :image, :image_digest, :source_image) SENSITIVE = [] include Aws::Structure end |