Class: Aws::Omics::Types::ImageMapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::ImageMapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Specifies image mappings that workflow tasks can use. For example, you can replace all the task references of a public image to use an equivalent image in your private ECR repository. You can use image mappings with upstream registries that don't support pull through cache. You need to manually synchronize the upstream registry with your private repository.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_image ⇒ String
Specifies the URI of the corresponding image in the private ECR registry.
-
#source_image ⇒ String
Specifies the URI of the source image in the upstream registry.
Instance Attribute Details
#destination_image ⇒ String
Specifies the URI of the corresponding image in the private ECR registry.
4974 4975 4976 4977 4978 4979 |
# File 'lib/aws-sdk-omics/types.rb', line 4974 class ImageMapping < Struct.new( :source_image, :destination_image) SENSITIVE = [] include Aws::Structure end |
#source_image ⇒ String
Specifies the URI of the source image in the upstream registry.
4974 4975 4976 4977 4978 4979 |
# File 'lib/aws-sdk-omics/types.rb', line 4974 class ImageMapping < Struct.new( :source_image, :destination_image) SENSITIVE = [] include Aws::Structure end |