Class: Aws::Omics::Types::InlineSetting
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::InlineSetting
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
A per-run configuration that overrides or merges with fields from
DefaultRunSetting for a specific run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#engine_settings ⇒ Hash, ...
Per-run engine-specific settings.
-
#name ⇒ String
An optional user-friendly name for this run.
-
#output_bucket_owner_id ⇒ String
The expected Amazon Web Services account ID of the owner of the output S3 bucket for this run.
-
#output_uri ⇒ String
Override the destination S3 URI for this run's outputs.
-
#parameters ⇒ Hash, ...
Per-run workflow parameters.
-
#priority ⇒ Integer
Override the priority for this run.
-
#run_setting_id ⇒ String
A customer-provided unique identifier for this run configuration within the batch.
-
#run_tags ⇒ Hash<String,String>
Per-run Amazon Web Services tags.
Instance Attribute Details
#engine_settings ⇒ Hash, ...
Per-run engine-specific settings. Use this field to specify
configuration options that are specific to the workflow engine (for
example, Nextflow profiles). Overrides
defaultRunSetting.engineSettings for this run.
5267 5268 5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 |
# File 'lib/aws-sdk-omics/types.rb', line 5267 class InlineSetting < Struct.new( :run_setting_id, :name, :output_uri, :priority, :parameters, :output_bucket_owner_id, :run_tags, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
An optional user-friendly name for this run.
5267 5268 5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 |
# File 'lib/aws-sdk-omics/types.rb', line 5267 class InlineSetting < Struct.new( :run_setting_id, :name, :output_uri, :priority, :parameters, :output_bucket_owner_id, :run_tags, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#output_bucket_owner_id ⇒ String
The expected Amazon Web Services account ID of the owner of the output S3 bucket for this run.
5267 5268 5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 |
# File 'lib/aws-sdk-omics/types.rb', line 5267 class InlineSetting < Struct.new( :run_setting_id, :name, :output_uri, :priority, :parameters, :output_bucket_owner_id, :run_tags, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#output_uri ⇒ String
Override the destination S3 URI for this run's outputs.
5267 5268 5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 |
# File 'lib/aws-sdk-omics/types.rb', line 5267 class InlineSetting < Struct.new( :run_setting_id, :name, :output_uri, :priority, :parameters, :output_bucket_owner_id, :run_tags, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash, ...
Per-run workflow parameters. Merged with
defaultRunSetting.parameters; values in this object take
precedence when keys overlap.
5267 5268 5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 |
# File 'lib/aws-sdk-omics/types.rb', line 5267 class InlineSetting < Struct.new( :run_setting_id, :name, :output_uri, :priority, :parameters, :output_bucket_owner_id, :run_tags, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
Override the priority for this run.
5267 5268 5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 |
# File 'lib/aws-sdk-omics/types.rb', line 5267 class InlineSetting < Struct.new( :run_setting_id, :name, :output_uri, :priority, :parameters, :output_bucket_owner_id, :run_tags, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#run_setting_id ⇒ String
A customer-provided unique identifier for this run configuration
within the batch. After submission, use ListRunsInBatch to map
each runSettingId to the HealthOmics-generated runId.
5267 5268 5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 |
# File 'lib/aws-sdk-omics/types.rb', line 5267 class InlineSetting < Struct.new( :run_setting_id, :name, :output_uri, :priority, :parameters, :output_bucket_owner_id, :run_tags, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#run_tags ⇒ Hash<String,String>
Per-run Amazon Web Services tags. Merged with
defaultRunSetting.runTags; values in this object take precedence
when keys overlap.
5267 5268 5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 |
# File 'lib/aws-sdk-omics/types.rb', line 5267 class InlineSetting < Struct.new( :run_setting_id, :name, :output_uri, :priority, :parameters, :output_bucket_owner_id, :run_tags, :engine_settings) SENSITIVE = [] include Aws::Structure end |