Class: Aws::Omics::Types::ListBatchResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::ListBatchResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::BatchListItem>
A list of batch summary objects.
-
#next_token ⇒ String
A pagination token to retrieve the next page of results.
Instance Attribute Details
#items ⇒ Array<Types::BatchListItem>
A list of batch summary objects. See BatchListItem.
5194 5195 5196 5197 5198 5199 |
# File 'lib/aws-sdk-omics/types.rb', line 5194 class ListBatchResponse < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token to retrieve the next page of results. Absent when no further results are available.
5194 5195 5196 5197 5198 5199 |
# File 'lib/aws-sdk-omics/types.rb', line 5194 class ListBatchResponse < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |