Class: Aws::Omics::Types::ListReadSetUploadPartsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::ListReadSetUploadPartsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
Next token returned in the response of a previous ListReadSetUploadParts call.
-
#parts ⇒ Array<Types::ReadSetUploadPartListItem>
An array of upload parts.
Instance Attribute Details
#next_token ⇒ String
Next token returned in the response of a previous ListReadSetUploadParts call. Used to get the next page of results.
5431 5432 5433 5434 5435 5436 |
# File 'lib/aws-sdk-omics/types.rb', line 5431 class ListReadSetUploadPartsResponse < Struct.new( :next_token, :parts) SENSITIVE = [] include Aws::Structure end |
#parts ⇒ Array<Types::ReadSetUploadPartListItem>
An array of upload parts.
5431 5432 5433 5434 5435 5436 |
# File 'lib/aws-sdk-omics/types.rb', line 5431 class ListReadSetUploadPartsResponse < Struct.new( :next_token, :parts) SENSITIVE = [] include Aws::Structure end |