Class: Aws::Omics::Types::ListRunGroupsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-omics/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of run groups to return in one page of results.

Returns:

  • (Integer)


6028
6029
6030
6031
6032
6033
6034
# File 'lib/aws-sdk-omics/types.rb', line 6028

class ListRunGroupsRequest < Struct.new(
  :name,
  :starting_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The run groups' name.

Returns:

  • (String)


6028
6029
6030
6031
6032
6033
6034
# File 'lib/aws-sdk-omics/types.rb', line 6028

class ListRunGroupsRequest < Struct.new(
  :name,
  :starting_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#starting_tokenString

Specify the pagination token from a previous request to retrieve the next page of results.

Returns:

  • (String)


6028
6029
6030
6031
6032
6033
6034
# File 'lib/aws-sdk-omics/types.rb', line 6028

class ListRunGroupsRequest < Struct.new(
  :name,
  :starting_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end