Class: Aws::Omics::Types::ReadOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::ReadOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Read options for an annotation import job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comment ⇒ String
The file’s comment character.
-
#encoding ⇒ String
The file’s encoding.
-
#escape ⇒ String
A character for escaping quotes in the file.
-
#escape_quotes ⇒ Boolean
Whether quotes need to be escaped in the file.
-
#header ⇒ Boolean
Whether the file has a header row.
-
#line_sep ⇒ String
A line separator for the file.
-
#quote ⇒ String
The file’s quote character.
-
#quote_all ⇒ Boolean
Whether all values need to be quoted, or just those that contain quotes.
-
#sep ⇒ String
The file’s field separator.
Instance Attribute Details
#comment ⇒ String
The file’s comment character.
6629 6630 6631 6632 6633 6634 6635 6636 6637 6638 6639 6640 6641 |
# File 'lib/aws-sdk-omics/types.rb', line 6629 class ReadOptions < Struct.new( :sep, :encoding, :quote, :quote_all, :escape, :escape_quotes, :comment, :header, :line_sep) SENSITIVE = [] include Aws::Structure end |
#encoding ⇒ String
The file’s encoding.
6629 6630 6631 6632 6633 6634 6635 6636 6637 6638 6639 6640 6641 |
# File 'lib/aws-sdk-omics/types.rb', line 6629 class ReadOptions < Struct.new( :sep, :encoding, :quote, :quote_all, :escape, :escape_quotes, :comment, :header, :line_sep) SENSITIVE = [] include Aws::Structure end |
#escape ⇒ String
A character for escaping quotes in the file.
6629 6630 6631 6632 6633 6634 6635 6636 6637 6638 6639 6640 6641 |
# File 'lib/aws-sdk-omics/types.rb', line 6629 class ReadOptions < Struct.new( :sep, :encoding, :quote, :quote_all, :escape, :escape_quotes, :comment, :header, :line_sep) SENSITIVE = [] include Aws::Structure end |
#escape_quotes ⇒ Boolean
Whether quotes need to be escaped in the file.
6629 6630 6631 6632 6633 6634 6635 6636 6637 6638 6639 6640 6641 |
# File 'lib/aws-sdk-omics/types.rb', line 6629 class ReadOptions < Struct.new( :sep, :encoding, :quote, :quote_all, :escape, :escape_quotes, :comment, :header, :line_sep) SENSITIVE = [] include Aws::Structure end |
#header ⇒ Boolean
Whether the file has a header row.
6629 6630 6631 6632 6633 6634 6635 6636 6637 6638 6639 6640 6641 |
# File 'lib/aws-sdk-omics/types.rb', line 6629 class ReadOptions < Struct.new( :sep, :encoding, :quote, :quote_all, :escape, :escape_quotes, :comment, :header, :line_sep) SENSITIVE = [] include Aws::Structure end |
#line_sep ⇒ String
A line separator for the file.
6629 6630 6631 6632 6633 6634 6635 6636 6637 6638 6639 6640 6641 |
# File 'lib/aws-sdk-omics/types.rb', line 6629 class ReadOptions < Struct.new( :sep, :encoding, :quote, :quote_all, :escape, :escape_quotes, :comment, :header, :line_sep) SENSITIVE = [] include Aws::Structure end |
#quote ⇒ String
The file’s quote character.
6629 6630 6631 6632 6633 6634 6635 6636 6637 6638 6639 6640 6641 |
# File 'lib/aws-sdk-omics/types.rb', line 6629 class ReadOptions < Struct.new( :sep, :encoding, :quote, :quote_all, :escape, :escape_quotes, :comment, :header, :line_sep) SENSITIVE = [] include Aws::Structure end |
#quote_all ⇒ Boolean
Whether all values need to be quoted, or just those that contain quotes.
6629 6630 6631 6632 6633 6634 6635 6636 6637 6638 6639 6640 6641 |
# File 'lib/aws-sdk-omics/types.rb', line 6629 class ReadOptions < Struct.new( :sep, :encoding, :quote, :quote_all, :escape, :escape_quotes, :comment, :header, :line_sep) SENSITIVE = [] include Aws::Structure end |
#sep ⇒ String
The file’s field separator.
6629 6630 6631 6632 6633 6634 6635 6636 6637 6638 6639 6640 6641 |
# File 'lib/aws-sdk-omics/types.rb', line 6629 class ReadOptions < Struct.new( :sep, :encoding, :quote, :quote_all, :escape, :escape_quotes, :comment, :header, :line_sep) SENSITIVE = [] include Aws::Structure end |