Class: Aws::Omics::Types::ReadSetListItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::ReadSetListItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
A read set.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The read set’s ARN.
-
#creation_time ⇒ Time
When the read set was created.
-
#creation_type ⇒ String
The creation type of the read set.
-
#description ⇒ String
The read set’s description.
-
#etag ⇒ Types::ETag
The entity tag (ETag) is a hash of the object representing its semantic content.
-
#file_type ⇒ String
The read set’s file type.
-
#id ⇒ String
The read set’s ID.
-
#name ⇒ String
The read set’s name.
-
#reference_arn ⇒ String
The read set’s genome reference ARN.
-
#sample_id ⇒ String
The read set’s sample ID.
-
#sequence_information ⇒ Types::SequenceInformation
Details about a sequence.
-
#sequence_store_id ⇒ String
The read set’s sequence store ID.
-
#status ⇒ String
The read set’s status.
-
#status_message ⇒ String
The status for a read set.
-
#subject_id ⇒ String
The read set’s subject ID.
Instance Attribute Details
#arn ⇒ String
The read set’s ARN.
6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/aws-sdk-omics/types.rb', line 6795 class ReadSetListItem < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :reference_arn, :file_type, :sequence_information, :creation_time, :status_message, :creation_type, :etag) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the read set was created.
6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/aws-sdk-omics/types.rb', line 6795 class ReadSetListItem < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :reference_arn, :file_type, :sequence_information, :creation_time, :status_message, :creation_type, :etag) SENSITIVE = [] include Aws::Structure end |
#creation_type ⇒ String
The creation type of the read set.
6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/aws-sdk-omics/types.rb', line 6795 class ReadSetListItem < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :reference_arn, :file_type, :sequence_information, :creation_time, :status_message, :creation_type, :etag) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The read set’s description.
6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/aws-sdk-omics/types.rb', line 6795 class ReadSetListItem < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :reference_arn, :file_type, :sequence_information, :creation_time, :status_message, :creation_type, :etag) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ Types::ETag
The entity tag (ETag) is a hash of the object representing its semantic content.
6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/aws-sdk-omics/types.rb', line 6795 class ReadSetListItem < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :reference_arn, :file_type, :sequence_information, :creation_time, :status_message, :creation_type, :etag) SENSITIVE = [] include Aws::Structure end |
#file_type ⇒ String
The read set’s file type.
6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/aws-sdk-omics/types.rb', line 6795 class ReadSetListItem < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :reference_arn, :file_type, :sequence_information, :creation_time, :status_message, :creation_type, :etag) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The read set’s ID.
6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/aws-sdk-omics/types.rb', line 6795 class ReadSetListItem < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :reference_arn, :file_type, :sequence_information, :creation_time, :status_message, :creation_type, :etag) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The read set’s name.
6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/aws-sdk-omics/types.rb', line 6795 class ReadSetListItem < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :reference_arn, :file_type, :sequence_information, :creation_time, :status_message, :creation_type, :etag) SENSITIVE = [] include Aws::Structure end |
#reference_arn ⇒ String
The read set’s genome reference ARN.
6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/aws-sdk-omics/types.rb', line 6795 class ReadSetListItem < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :reference_arn, :file_type, :sequence_information, :creation_time, :status_message, :creation_type, :etag) SENSITIVE = [] include Aws::Structure end |
#sample_id ⇒ String
The read set’s sample ID.
6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/aws-sdk-omics/types.rb', line 6795 class ReadSetListItem < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :reference_arn, :file_type, :sequence_information, :creation_time, :status_message, :creation_type, :etag) SENSITIVE = [] include Aws::Structure end |
#sequence_information ⇒ Types::SequenceInformation
Details about a sequence.
6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/aws-sdk-omics/types.rb', line 6795 class ReadSetListItem < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :reference_arn, :file_type, :sequence_information, :creation_time, :status_message, :creation_type, :etag) SENSITIVE = [] include Aws::Structure end |
#sequence_store_id ⇒ String
The read set’s sequence store ID.
6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/aws-sdk-omics/types.rb', line 6795 class ReadSetListItem < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :reference_arn, :file_type, :sequence_information, :creation_time, :status_message, :creation_type, :etag) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The read set’s status.
6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/aws-sdk-omics/types.rb', line 6795 class ReadSetListItem < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :reference_arn, :file_type, :sequence_information, :creation_time, :status_message, :creation_type, :etag) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The status for a read set. It provides more detail as to why the read set has a status.
6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/aws-sdk-omics/types.rb', line 6795 class ReadSetListItem < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :reference_arn, :file_type, :sequence_information, :creation_time, :status_message, :creation_type, :etag) SENSITIVE = [] include Aws::Structure end |
#subject_id ⇒ String
The read set’s subject ID.
6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/aws-sdk-omics/types.rb', line 6795 class ReadSetListItem < Struct.new( :id, :arn, :sequence_store_id, :subject_id, :sample_id, :status, :name, :description, :reference_arn, :file_type, :sequence_information, :creation_time, :status_message, :creation_type, :etag) SENSITIVE = [] include Aws::Structure end |