Class: Aws::Omics::Types::ShareDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::ShareDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
The details of a resource share.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The timestamp of when the resource share was created.
-
#owner_id ⇒ String
The account ID for the data owner.
-
#principal_subscriber ⇒ String
The principal subscriber is the account that is sharing the resource.
-
#resource_arn ⇒ String
The Arn of the shared resource.
-
#resource_id ⇒ String
The ID of the shared resource.
-
#share_id ⇒ String
The ID of the resource share.
-
#share_name ⇒ String
The name of the resource share.
-
#status ⇒ String
The status of the share.
-
#status_message ⇒ String
The status message for a resource share.
-
#update_time ⇒ Time
The timestamp of the resource share update.
Instance Attribute Details
#creation_time ⇒ Time
The timestamp of when the resource share was created.
7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-omics/types.rb', line 7699 class ShareDetails < Struct.new( :share_id, :resource_arn, :resource_id, :principal_subscriber, :owner_id, :status, :status_message, :share_name, :creation_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The account ID for the data owner. The owner creates the resource share.
7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-omics/types.rb', line 7699 class ShareDetails < Struct.new( :share_id, :resource_arn, :resource_id, :principal_subscriber, :owner_id, :status, :status_message, :share_name, :creation_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#principal_subscriber ⇒ String
The principal subscriber is the account that is sharing the resource.
7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-omics/types.rb', line 7699 class ShareDetails < Struct.new( :share_id, :resource_arn, :resource_id, :principal_subscriber, :owner_id, :status, :status_message, :share_name, :creation_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Arn of the shared resource.
7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-omics/types.rb', line 7699 class ShareDetails < Struct.new( :share_id, :resource_arn, :resource_id, :principal_subscriber, :owner_id, :status, :status_message, :share_name, :creation_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The ID of the shared resource.
7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-omics/types.rb', line 7699 class ShareDetails < Struct.new( :share_id, :resource_arn, :resource_id, :principal_subscriber, :owner_id, :status, :status_message, :share_name, :creation_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#share_id ⇒ String
The ID of the resource share.
7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-omics/types.rb', line 7699 class ShareDetails < Struct.new( :share_id, :resource_arn, :resource_id, :principal_subscriber, :owner_id, :status, :status_message, :share_name, :creation_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#share_name ⇒ String
The name of the resource share.
7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-omics/types.rb', line 7699 class ShareDetails < Struct.new( :share_id, :resource_arn, :resource_id, :principal_subscriber, :owner_id, :status, :status_message, :share_name, :creation_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the share.
7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-omics/types.rb', line 7699 class ShareDetails < Struct.new( :share_id, :resource_arn, :resource_id, :principal_subscriber, :owner_id, :status, :status_message, :share_name, :creation_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The status message for a resource share. It provides additional details about the share status.
7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-omics/types.rb', line 7699 class ShareDetails < Struct.new( :share_id, :resource_arn, :resource_id, :principal_subscriber, :owner_id, :status, :status_message, :share_name, :creation_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The timestamp of the resource share update.
7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-omics/types.rb', line 7699 class ShareDetails < Struct.new( :share_id, :resource_arn, :resource_id, :principal_subscriber, :owner_id, :status, :status_message, :share_name, :creation_time, :update_time) SENSITIVE = [] include Aws::Structure end |