Class: Aws::Omics::Types::SourceReference

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-omics/types.rb

Overview

Contains information about the source reference in a code repository, such as a branch, tag, or commit.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#typeString

The type of source reference, such as branch, tag, or commit.

Returns:

  • (String)


7780
7781
7782
7783
7784
7785
# File 'lib/aws-sdk-omics/types.rb', line 7780

class SourceReference < Struct.new(
  :type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value of the source reference, such as the branch name, tag name, or commit ID.

Returns:

  • (String)


7780
7781
7782
7783
7784
7785
# File 'lib/aws-sdk-omics/types.rb', line 7780

class SourceReference < Struct.new(
  :type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end