Class: Aws::Omics::Types::StartRunRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-omics/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cache_behaviorString

The cache behavior for the run. You specify this value if you want to override the default behavior for the cache. You had set the default value when you created the cache. For more information, see

Run cache behavior][1

in the *Amazon Web Services HealthOmics User

Guide*.

[1]: docs.aws.amazon.com/omics/latest/dev/how-run-cache.html#run-cache-behavior

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#cache_idString

Identifier of the cache associated with this run. If you don’t specify a cache ID, no task outputs are cached for this run.

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#configuration_nameString

Optional configuration name to use for the workflow run.

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#engine_settingsHash, ...

Engine-specific settings for the workflow run. Use this field to specify configuration options that are specific to the workflow engine (for example, Nextflow profiles).

Returns:

  • (Hash, Array, String, Numeric, Boolean)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

A log level for the run.

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A name for the run. This is recommended to view and organize runs in the Amazon Web Services HealthOmics console and CloudWatch logs.

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#networking_modeString

Optional configuration for run networking behavior. If not specified, this will default to RESTRICTED.

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#output_uriString

An output S3 URI for the run. The S3 bucket must be in the same region as the workflow. The role ARN must have permission to write to this S3 bucket.

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash, ...

Parameters for the run. The run needs all required parameters and can include optional parameters. The run cannot include any parameters that are not defined in the parameter template. To retrieve parameters from the run, use the GetRun API operation.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#priorityInteger

Use the run priority (highest: 1) to establish the order of runs in a run group when you start a run. If multiple runs share the same priority, the run that was initiated first will have the higher priority. Runs that do not belong to a run group can be assigned a priority. The priorities of these runs are ranked among other runs that are not in a run group. For more information, see [Run priority] in the *Amazon Web Services HealthOmics User Guide*.

[1]: docs.aws.amazon.com/omics/latest/dev/creating-run-groups.html#run-priority

Returns:

  • (Integer)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

An idempotency token used to dedupe retry requests so that duplicate runs are not created.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#retention_modeString

The retention mode for the run. The default value is ‘RETAIN`.

Amazon Web Services HealthOmics stores a fixed number of runs that are available to the console and API. In the default mode (‘RETAIN`), you need to remove runs manually when the number of run exceeds the maximum. If you set the retention mode to `REMOVE`, Amazon Web Services HealthOmics automatically removes runs (that have mode set to `REMOVE`) when the number of run exceeds the maximum. All run logs are available in CloudWatch logs, if you need information about a run that is no longer available to the API.

For more information about retention mode, see [Specifying run retention mode] in the *Amazon Web Services HealthOmics User Guide*.

[1]: docs.aws.amazon.com/omics/latest/dev/starting-a-run.html

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

A service role for the run. The ‘roleArn` requires access to Amazon Web Services HealthOmics, S3, Cloudwatch logs, and EC2. An example `roleArn` is `arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ`. In this example, the AWS account ID is `123456789012` and the role name is `omics-service-role-serviceRole-W8O1XMPL7QZ`.

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#run_group_idString

The run’s group ID. Use a run group to cap the compute resources (and number of concurrent runs) for the runs that you add to the run group.

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#run_idString

The ID of a run to duplicate.

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#scratch_storage_modeString

Optional configuration for enabling scratch ephemeral storage mounted at /tmp. If not specified, this will default to SHARED. This configuration is applicable only for CPU tasks. For tasks using GPUs, scratch storage is always LOCAL.

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#storage_capacityInteger

The ‘STATIC` storage capacity (in gibibytes, GiB) for this run. The default run storage capacity is 1200 GiB. If your requested storage capacity is unavailable, the system rounds up the value to the nearest 1200 GiB multiple. If the requested storage capacity is still unavailable, the system rounds up the value to the nearest 2400 GiB multiple. This field is not required if the storage type is `DYNAMIC` (the system ignores any value that you enter).

Returns:

  • (Integer)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The storage type for the run. If you set the storage type to ‘DYNAMIC`, Amazon Web Services HealthOmics dynamically scales the storage up or down, based on file system utilization. By default, the run uses `STATIC` storage type, which allocates a fixed amount of storage. For more information about `DYNAMIC` and `STATIC` storage, see [Run storage types] in the *Amazon Web Services HealthOmics User Guide*.

[1]: docs.aws.amazon.com/omics/latest/dev/workflows-run-types.html

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Tags for the run. You can add up to 50 tags per run. For more information, see [Adding a tag] in the *Amazon Web Services HealthOmics User Guide*.

[1]: docs.aws.amazon.com/omics/latest/dev/add-a-tag.html

Returns:

  • (Hash<String,String>)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_idString

The run’s workflow ID. The ‘workflowId` is not the UUID.

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_owner_idString

The 12-digit account ID of the workflow owner that is used for running a shared workflow. The workflow owner ID can be retrieved using the ‘GetShare` API operation. If you are the workflow owner, you do not need to include this ID.

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_typeString

The run’s workflow type. The ‘workflowType` must be specified if you are running a `READY2RUN` workflow. If you are running a `PRIVATE` workflow (default), you do not need to include the workflow type.

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_version_nameString

The name of the workflow version. Use workflow versions to track and organize changes to the workflow. If your workflow has multiple versions, the run uses the default version unless you specify a version name. To learn more, see [Workflow versioning] in the *Amazon Web Services HealthOmics User Guide*.

[1]: docs.aws.amazon.com/omics/latest/dev/workflow-versions.html

Returns:

  • (String)


8490
8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
# File 'lib/aws-sdk-omics/types.rb', line 8490

class StartRunRequest < Struct.new(
  :workflow_id,
  :workflow_type,
  :run_id,
  :role_arn,
  :name,
  :cache_id,
  :cache_behavior,
  :run_group_id,
  :priority,
  :parameters,
  :storage_capacity,
  :output_uri,
  :log_level,
  :tags,
  :request_id,
  :retention_mode,
  :storage_type,
  :workflow_owner_id,
  :workflow_version_name,
  :networking_mode,
  :scratch_storage_mode,
  :configuration_name,
  :engine_settings)
  SENSITIVE = []
  include Aws::Structure
end