Class: Aws::Omics::Types::StoreOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-omics/types.rb

Overview

Note:

StoreOptions is a union - when making an API calls you must set exactly one of the members.

Note:

StoreOptions is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of StoreOptions corresponding to the set member.

Settings for a store.

Direct Known Subclasses

TsvStoreOptions, Unknown

Defined Under Namespace

Classes: TsvStoreOptions, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#tsv_store_optionsTypes::TsvStoreOptions

File settings for a TSV store.



8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
# File 'lib/aws-sdk-omics/types.rb', line 8537

class StoreOptions < Struct.new(
  :tsv_store_options,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class TsvStoreOptions < StoreOptions; end
  class Unknown < StoreOptions; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



8537
8538
8539
# File 'lib/aws-sdk-omics/types.rb', line 8537

def unknown
  @unknown
end