Class: Aws::Omics::Types::TaskListItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::TaskListItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
A workflow run task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_hit ⇒ Boolean
Set to true if Amazon Web Services HealthOmics found a matching entry in the run cache for this task.
-
#cache_s3_uri ⇒ String
The S3 URI of the cache location.
-
#cpus ⇒ Integer
The task's CPU count.
-
#creation_time ⇒ Time
When the task was created.
-
#gpus ⇒ Integer
The number of Graphics Processing Units (GPU) specified for the task.
-
#instance_type ⇒ String
The instance type for a task.
-
#memory ⇒ Integer
The task's memory use in gigabyes.
-
#name ⇒ String
The task's name.
-
#start_time ⇒ Time
When the task started.
-
#status ⇒ String
The task's status.
-
#stop_time ⇒ Time
When the task stopped.
-
#task_id ⇒ String
The task's ID.
-
#uuid ⇒ String
The universally unique identifier (UUID) for the workflow task.
Instance Attribute Details
#cache_hit ⇒ Boolean
Set to true if Amazon Web Services HealthOmics found a matching entry in the run cache for this task.
8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 |
# File 'lib/aws-sdk-omics/types.rb', line 8782 class TaskListItem < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :gpus, :instance_type, :uuid) SENSITIVE = [] include Aws::Structure end |
#cache_s3_uri ⇒ String
The S3 URI of the cache location.
8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 |
# File 'lib/aws-sdk-omics/types.rb', line 8782 class TaskListItem < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :gpus, :instance_type, :uuid) SENSITIVE = [] include Aws::Structure end |
#cpus ⇒ Integer
The task's CPU count.
8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 |
# File 'lib/aws-sdk-omics/types.rb', line 8782 class TaskListItem < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :gpus, :instance_type, :uuid) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the task was created.
8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 |
# File 'lib/aws-sdk-omics/types.rb', line 8782 class TaskListItem < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :gpus, :instance_type, :uuid) SENSITIVE = [] include Aws::Structure end |
#gpus ⇒ Integer
The number of Graphics Processing Units (GPU) specified for the task.
8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 |
# File 'lib/aws-sdk-omics/types.rb', line 8782 class TaskListItem < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :gpus, :instance_type, :uuid) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type for a task.
8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 |
# File 'lib/aws-sdk-omics/types.rb', line 8782 class TaskListItem < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :gpus, :instance_type, :uuid) SENSITIVE = [] include Aws::Structure end |
#memory ⇒ Integer
The task's memory use in gigabyes.
8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 |
# File 'lib/aws-sdk-omics/types.rb', line 8782 class TaskListItem < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :gpus, :instance_type, :uuid) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The task's name.
8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 |
# File 'lib/aws-sdk-omics/types.rb', line 8782 class TaskListItem < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :gpus, :instance_type, :uuid) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
When the task started.
8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 |
# File 'lib/aws-sdk-omics/types.rb', line 8782 class TaskListItem < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :gpus, :instance_type, :uuid) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The task's status.
8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 |
# File 'lib/aws-sdk-omics/types.rb', line 8782 class TaskListItem < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :gpus, :instance_type, :uuid) SENSITIVE = [] include Aws::Structure end |
#stop_time ⇒ Time
When the task stopped.
8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 |
# File 'lib/aws-sdk-omics/types.rb', line 8782 class TaskListItem < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :gpus, :instance_type, :uuid) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The task's ID.
8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 |
# File 'lib/aws-sdk-omics/types.rb', line 8782 class TaskListItem < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :gpus, :instance_type, :uuid) SENSITIVE = [] include Aws::Structure end |
#uuid ⇒ String
The universally unique identifier (UUID) for the workflow task.
8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 |
# File 'lib/aws-sdk-omics/types.rb', line 8782 class TaskListItem < Struct.new( :task_id, :status, :name, :cpus, :cache_hit, :cache_s3_uri, :memory, :creation_time, :start_time, :stop_time, :gpus, :instance_type, :uuid) SENSITIVE = [] include Aws::Structure end |