Class: Aws::Omics::Types::UpdateRunCacheRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::UpdateRunCacheRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_behavior ⇒ String
Update the default run cache behavior.
-
#description ⇒ String
Update the run cache description.
-
#id ⇒ String
The identifier of the run cache you want to update.
-
#name ⇒ String
Update the name of the run cache.
Instance Attribute Details
#cache_behavior ⇒ String
Update the default run cache behavior.
8996 8997 8998 8999 9000 9001 9002 9003 |
# File 'lib/aws-sdk-omics/types.rb', line 8996 class UpdateRunCacheRequest < Struct.new( :cache_behavior, :description, :id, :name) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Update the run cache description.
8996 8997 8998 8999 9000 9001 9002 9003 |
# File 'lib/aws-sdk-omics/types.rb', line 8996 class UpdateRunCacheRequest < Struct.new( :cache_behavior, :description, :id, :name) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the run cache you want to update.
8996 8997 8998 8999 9000 9001 9002 9003 |
# File 'lib/aws-sdk-omics/types.rb', line 8996 class UpdateRunCacheRequest < Struct.new( :cache_behavior, :description, :id, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Update the name of the run cache.
8996 8997 8998 8999 9000 9001 9002 9003 |
# File 'lib/aws-sdk-omics/types.rb', line 8996 class UpdateRunCacheRequest < Struct.new( :cache_behavior, :description, :id, :name) SENSITIVE = [] include Aws::Structure end |