Class: Aws::Omics::Types::UploadReadSetPartResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::UploadReadSetPartResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#checksum ⇒ String
An identifier used to confirm that parts are being added to the intended upload.
Instance Attribute Details
#checksum ⇒ String
An identifier used to confirm that parts are being added to the intended upload.
9302 9303 9304 9305 9306 |
# File 'lib/aws-sdk-omics/types.rb', line 9302 class UploadReadSetPartResponse < Struct.new( :checksum) SENSITIVE = [] include Aws::Structure end |