Class: Aws::Omics::Types::VariantImportJobItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::VariantImportJobItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
A variant import job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#annotation_fields ⇒ Hash<String,String>
The annotation schema generated by the parsed annotation data.
-
#completion_time ⇒ Time
When the job completed.
-
#creation_time ⇒ Time
When the job was created.
-
#destination_name ⇒ String
The job’s destination variant store.
-
#id ⇒ String
The job’s ID.
-
#role_arn ⇒ String
The job’s service role ARN.
-
#run_left_normalization ⇒ Boolean
The job’s left normalization setting.
-
#status ⇒ String
The job’s status.
-
#update_time ⇒ Time
When the job was updated.
Instance Attribute Details
#annotation_fields ⇒ Hash<String,String>
The annotation schema generated by the parsed annotation data.
9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 |
# File 'lib/aws-sdk-omics/types.rb', line 9455 class VariantImportJobItem < Struct.new( :id, :destination_name, :role_arn, :status, :creation_time, :update_time, :completion_time, :run_left_normalization, :annotation_fields) SENSITIVE = [] include Aws::Structure end |
#completion_time ⇒ Time
When the job completed.
9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 |
# File 'lib/aws-sdk-omics/types.rb', line 9455 class VariantImportJobItem < Struct.new( :id, :destination_name, :role_arn, :status, :creation_time, :update_time, :completion_time, :run_left_normalization, :annotation_fields) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the job was created.
9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 |
# File 'lib/aws-sdk-omics/types.rb', line 9455 class VariantImportJobItem < Struct.new( :id, :destination_name, :role_arn, :status, :creation_time, :update_time, :completion_time, :run_left_normalization, :annotation_fields) SENSITIVE = [] include Aws::Structure end |
#destination_name ⇒ String
The job’s destination variant store.
9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 |
# File 'lib/aws-sdk-omics/types.rb', line 9455 class VariantImportJobItem < Struct.new( :id, :destination_name, :role_arn, :status, :creation_time, :update_time, :completion_time, :run_left_normalization, :annotation_fields) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The job’s ID.
9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 |
# File 'lib/aws-sdk-omics/types.rb', line 9455 class VariantImportJobItem < Struct.new( :id, :destination_name, :role_arn, :status, :creation_time, :update_time, :completion_time, :run_left_normalization, :annotation_fields) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The job’s service role ARN.
9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 |
# File 'lib/aws-sdk-omics/types.rb', line 9455 class VariantImportJobItem < Struct.new( :id, :destination_name, :role_arn, :status, :creation_time, :update_time, :completion_time, :run_left_normalization, :annotation_fields) SENSITIVE = [] include Aws::Structure end |
#run_left_normalization ⇒ Boolean
The job’s left normalization setting.
9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 |
# File 'lib/aws-sdk-omics/types.rb', line 9455 class VariantImportJobItem < Struct.new( :id, :destination_name, :role_arn, :status, :creation_time, :update_time, :completion_time, :run_left_normalization, :annotation_fields) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The job’s status.
9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 |
# File 'lib/aws-sdk-omics/types.rb', line 9455 class VariantImportJobItem < Struct.new( :id, :destination_name, :role_arn, :status, :creation_time, :update_time, :completion_time, :run_left_normalization, :annotation_fields) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
When the job was updated.
9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 |
# File 'lib/aws-sdk-omics/types.rb', line 9455 class VariantImportJobItem < Struct.new( :id, :destination_name, :role_arn, :status, :creation_time, :update_time, :completion_time, :run_left_normalization, :annotation_fields) SENSITIVE = [] include Aws::Structure end |