Class: Aws::Omics::Types::VersionDeleteError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::VersionDeleteError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
The error preventing deletion of the annotation store version.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The message explaining the error in annotation store deletion.
-
#version_name ⇒ String
The name given to an annotation store version.
Instance Attribute Details
#message ⇒ String
The message explaining the error in annotation store deletion.
9569 9570 9571 9572 9573 9574 |
# File 'lib/aws-sdk-omics/types.rb', line 9569 class VersionDeleteError < Struct.new( :version_name, :message) SENSITIVE = [] include Aws::Structure end |
#version_name ⇒ String
The name given to an annotation store version.
9569 9570 9571 9572 9573 9574 |
# File 'lib/aws-sdk-omics/types.rb', line 9569 class VersionDeleteError < Struct.new( :version_name, :message) SENSITIVE = [] include Aws::Structure end |