Class: Aws::Omics::Waiters::AnnotationStoreDeleted
- Inherits:
-
Object
- Object
- Aws::Omics::Waiters::AnnotationStoreDeleted
- Defined in:
- lib/aws-sdk-omics/waiters.rb,
sig/waiters.rbs
Overview
Wait until an annotation store is deleted.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ AnnotationStoreDeleted
constructor
A new instance of AnnotationStoreDeleted.
-
#wait(params = {}) ⇒ Types::GetAnnotationStoreResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ AnnotationStoreDeleted
Returns a new instance of AnnotationStoreDeleted.
222 223 |
# File 'lib/aws-sdk-omics/waiters.rb', line 222
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
259 260 261 |
# File 'lib/aws-sdk-omics/waiters.rb', line 259 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetAnnotationStoreResponse
Returns a response object which responds to the following methods:
- #id => String
- #reference => Types::ReferenceItem
- #status => String
- #store_arn => String
- #name => String
- #description => String
- #sse_config => Types::SseConfig
- #creation_time => Time
- #update_time => Time
- #tags => Hash<String,String>
- #store_options => Types::StoreOptions
- #store_format => String
- #status_message => String
- #store_size_bytes => Integer
- #num_versions => Integer
254 |
# File 'lib/aws-sdk-omics/waiters.rb', line 254
def wait: (
|