Class: Aws::Omics::Waiters::AnnotationStoreVersionCreated
- Inherits:
-
Object
- Object
- Aws::Omics::Waiters::AnnotationStoreVersionCreated
- Defined in:
- lib/aws-sdk-omics/waiters.rb,
sig/waiters.rbs
Overview
Wait until an annotation store version is created
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ AnnotationStoreVersionCreated
constructor
A new instance of AnnotationStoreVersionCreated.
-
#wait(params = {}) ⇒ Types::GetAnnotationStoreVersionResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ AnnotationStoreVersionCreated
Returns a new instance of AnnotationStoreVersionCreated.
272 273 |
# File 'lib/aws-sdk-omics/waiters.rb', line 272
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
316 317 318 |
# File 'lib/aws-sdk-omics/waiters.rb', line 316 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetAnnotationStoreVersionResponse
Returns a response object which responds to the following methods:
- #store_id => String
- #id => String
- #status => String
- #version_arn => String
- #name => String
- #version_name => String
- #description => String
- #creation_time => Time
- #update_time => Time
- #tags => Hash<String,String>
- #version_options => Types::VersionOptions
- #status_message => String
- #version_size_bytes => Integer
311 |
# File 'lib/aws-sdk-omics/waiters.rb', line 311
def wait: (
|