Class: Aws::Omics::Waiters::RunCompleted
- Inherits:
-
Object
- Object
- Aws::Omics::Waiters::RunCompleted
- Defined in:
- lib/aws-sdk-omics/waiters.rb,
sig/waiters.rbs
Overview
Wait until a run is completed.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ RunCompleted
constructor
A new instance of RunCompleted.
-
#wait(params = {}) ⇒ Types::GetRunResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ RunCompleted
Returns a new instance of RunCompleted.
679 680 |
# File 'lib/aws-sdk-omics/waiters.rb', line 679
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
735 736 737 |
# File 'lib/aws-sdk-omics/waiters.rb', line 735 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetRunResponse
Returns a response object which responds to the following methods:
- #arn => String
- #id => String
- #cache_id => String
- #cache_behavior => String
- #engine_version => String
- #status => String
- #workflow_id => String
- #workflow_type => String
- #run_id => String
- #role_arn => String
- #name => String
- #run_group_id => String
- #batch_id => String
- #priority => Integer
- #definition => String
- #digest => String
- #parameters => Hash,Array,String,Numeric,Boolean
- #storage_capacity => Integer
- #output_uri => String
- #log_level => String
- #resource_digests => Hash<String,String>
- #started_by => String
- #creation_time => Time
- #start_time => Time
- #stop_time => Time
- #status_message => String
- #tags => Hash<String,String>
- #accelerators => String
- #retention_mode => String
- #failure_reason => String
- #log_location => Types::RunLogLocation
- #uuid => String
- #run_output_uri => String
- #storage_type => String
- #workflow_owner_id => String
- #workflow_version_name => String
- #workflow_uuid => String
- #networking_mode => String
- #scratch_storage_mode => String
- #configuration => Types::ConfigurationDetails
- #vpc_config => Types::VpcConfigResponse
- #engine_settings => Hash,Array,String,Numeric,Boolean
730 |
# File 'lib/aws-sdk-omics/waiters.rb', line 730
def wait: (
|