Class: Aws::Omics::Waiters::TaskRunning
- Inherits:
-
Object
- Object
- Aws::Omics::Waiters::TaskRunning
- Defined in:
- lib/aws-sdk-omics/waiters.rb,
sig/waiters.rbs
Overview
Wait until a task is running.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ TaskRunning
constructor
A new instance of TaskRunning.
-
#wait(params = {}) ⇒ Types::GetRunTaskResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ TaskRunning
Returns a new instance of TaskRunning.
880 881 |
# File 'lib/aws-sdk-omics/waiters.rb', line 880
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
930 931 932 |
# File 'lib/aws-sdk-omics/waiters.rb', line 930 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetRunTaskResponse
Returns a response object which responds to the following methods:
- #task_id => String
- #status => String
- #name => String
- #cpus => Integer
- #cache_hit => Boolean
- #cache_s3_uri => String
- #memory => Integer
- #creation_time => Time
- #start_time => Time
- #stop_time => Time
- #status_message => String
- #log_stream => String
- #gpus => Integer
- #instance_type => String
- #failure_reason => String
- #image_details => Types::ImageDetails
925 |
# File 'lib/aws-sdk-omics/waiters.rb', line 925
def wait: (
|