Class: Aws::Omics::Waiters::VariantStoreDeleted
- Inherits:
-
Object
- Object
- Aws::Omics::Waiters::VariantStoreDeleted
- Defined in:
- lib/aws-sdk-omics/waiters.rb,
sig/waiters.rbs
Overview
Wait until a variant store is deleted.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ VariantStoreDeleted
constructor
A new instance of VariantStoreDeleted.
-
#wait(params = {}) ⇒ Types::GetVariantStoreResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ VariantStoreDeleted
Returns a new instance of VariantStoreDeleted.
1063 1064 |
# File 'lib/aws-sdk-omics/waiters.rb', line 1063
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1100 1101 1102 |
# File 'lib/aws-sdk-omics/waiters.rb', line 1100 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetVariantStoreResponse
Returns a response object which responds to the following methods:
- #id => String
- #reference => Types::ReferenceItem
- #status => String
- #store_arn => String
- #name => String
- #description => String
- #sse_config => Types::SseConfig
- #creation_time => Time
- #update_time => Time
- #tags => Hash<String,String>
- #status_message => String
- #store_size_bytes => Integer
1095 |
# File 'lib/aws-sdk-omics/waiters.rb', line 1095
def wait: (
|