Class: Aws::Omics::Waiters::WorkflowVersionActive

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-omics/waiters.rb,
sig/waiters.rbs

Overview

Wait until a workflow version is active.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ WorkflowVersionActive

Returns a new instance of WorkflowVersionActive.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 10
  • :delay (Integer) — default: 3
  • :before_attempt (Proc)
  • :before_wait (Proc)


1170
1171
# File 'lib/aws-sdk-omics/waiters.rb', line 1170

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1214
1215
1216
# File 'lib/aws-sdk-omics/waiters.rb', line 1214

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetWorkflowVersionResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :workflow_id (required, String)

    The workflow's ID. The workflowId is not the UUID.

  • :version_name (required, String)

    The workflow version name.

  • :type (String)

    The workflow's type.

  • :export (Array<String>)

    The export format for the workflow.

  • :workflow_owner_id (String)

    The 12-digit account ID of the workflow owner. The workflow owner ID can be retrieved using the GetShare API operation. If you are the workflow owner, you do not need to include this ID.

Returns:



1209
# File 'lib/aws-sdk-omics/waiters.rb', line 1209

def wait: (