Class: Aws::Omics::Types::CreateSequenceStoreRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::CreateSequenceStoreRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
An idempotency token used to dedupe retry requests so that duplicate runs are not created.
-
#description ⇒ String
A description for the store.
-
#e_tag_algorithm_family ⇒ String
The ETag algorithm family to use for ingested read sets.
-
#fallback_location ⇒ String
An S3 location that is used to store files that have failed a direct upload.
-
#name ⇒ String
A name for the store.
-
#propagated_set_level_tags ⇒ Array<String>
The tags keys to propagate to the S3 objects associated with read sets in the sequence store.
-
#s3_access_config ⇒ Types::S3AccessConfig
S3 access configuration parameters.
-
#sse_config ⇒ Types::SseConfig
Server-side encryption (SSE) settings for the store.
-
#tags ⇒ Hash<String,String>
Tags for the store.
Instance Attribute Details
#client_token ⇒ String
An idempotency token used to dedupe retry requests so that duplicate runs are not created.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'lib/aws-sdk-omics/types.rb', line 1385 class CreateSequenceStoreRequest < Struct.new( :name, :description, :sse_config, :tags, :client_token, :fallback_location, :e_tag_algorithm_family, :propagated_set_level_tags, :s3_access_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the store.
1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'lib/aws-sdk-omics/types.rb', line 1385 class CreateSequenceStoreRequest < Struct.new( :name, :description, :sse_config, :tags, :client_token, :fallback_location, :e_tag_algorithm_family, :propagated_set_level_tags, :s3_access_config) SENSITIVE = [] include Aws::Structure end |
#e_tag_algorithm_family ⇒ String
The ETag algorithm family to use for ingested read sets. The default value is MD5up. For more information on ETags, see [ETags and data provenance] in the *Amazon Web Services HealthOmics User Guide*.
[1]: docs.aws.amazon.com/omics/latest/dev/etags-and-provenance.html
1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'lib/aws-sdk-omics/types.rb', line 1385 class CreateSequenceStoreRequest < Struct.new( :name, :description, :sse_config, :tags, :client_token, :fallback_location, :e_tag_algorithm_family, :propagated_set_level_tags, :s3_access_config) SENSITIVE = [] include Aws::Structure end |
#fallback_location ⇒ String
An S3 location that is used to store files that have failed a direct upload. You can add or change the ‘fallbackLocation` after creating a sequence store. This is not required if you are uploading files from a different S3 bucket.
1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'lib/aws-sdk-omics/types.rb', line 1385 class CreateSequenceStoreRequest < Struct.new( :name, :description, :sse_config, :tags, :client_token, :fallback_location, :e_tag_algorithm_family, :propagated_set_level_tags, :s3_access_config) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the store.
1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'lib/aws-sdk-omics/types.rb', line 1385 class CreateSequenceStoreRequest < Struct.new( :name, :description, :sse_config, :tags, :client_token, :fallback_location, :e_tag_algorithm_family, :propagated_set_level_tags, :s3_access_config) SENSITIVE = [] include Aws::Structure end |
#propagated_set_level_tags ⇒ Array<String>
The tags keys to propagate to the S3 objects associated with read sets in the sequence store. These tags can be used as input to add metadata to your read sets.
1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'lib/aws-sdk-omics/types.rb', line 1385 class CreateSequenceStoreRequest < Struct.new( :name, :description, :sse_config, :tags, :client_token, :fallback_location, :e_tag_algorithm_family, :propagated_set_level_tags, :s3_access_config) SENSITIVE = [] include Aws::Structure end |
#s3_access_config ⇒ Types::S3AccessConfig
S3 access configuration parameters. This specifies the parameters needed to access logs stored in S3 buckets. The S3 bucket must be in the same region and account as the sequence store.
1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'lib/aws-sdk-omics/types.rb', line 1385 class CreateSequenceStoreRequest < Struct.new( :name, :description, :sse_config, :tags, :client_token, :fallback_location, :e_tag_algorithm_family, :propagated_set_level_tags, :s3_access_config) SENSITIVE = [] include Aws::Structure end |
#sse_config ⇒ Types::SseConfig
Server-side encryption (SSE) settings for the store.
1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'lib/aws-sdk-omics/types.rb', line 1385 class CreateSequenceStoreRequest < Struct.new( :name, :description, :sse_config, :tags, :client_token, :fallback_location, :e_tag_algorithm_family, :propagated_set_level_tags, :s3_access_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags for the store. You can configure up to 50 tags.
1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'lib/aws-sdk-omics/types.rb', line 1385 class CreateSequenceStoreRequest < Struct.new( :name, :description, :sse_config, :tags, :client_token, :fallback_location, :e_tag_algorithm_family, :propagated_set_level_tags, :s3_access_config) SENSITIVE = [] include Aws::Structure end |