Class: Aws::Omics::Types::DefaultRunSetting
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::DefaultRunSetting
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Shared configuration applied to all runs in a batch. Fields specified in a per-run ‘InlineSetting` entry override the corresponding fields in this object for that run. The `parameters` and `runTags` fields are merged rather than replaced — run-specific values take precedence when keys overlap.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_behavior ⇒ String
The cache behavior for the runs.
-
#cache_id ⇒ String
The identifier of the run cache to associate with the runs.
-
#configuration_name ⇒ String
Optional configuration name to use for the workflow run.
-
#engine_settings ⇒ Hash, ...
Engine-specific settings for the workflow run.
-
#log_level ⇒ String
The verbosity level for CloudWatch Logs emitted during each run.
-
#name ⇒ String
An optional user-friendly name applied to each workflow run.
-
#networking_mode ⇒ String
Optional configuration for run networking behavior.
-
#output_bucket_owner_id ⇒ String
The expected AWS account ID of the owner of the output S3 bucket.
-
#output_uri ⇒ String
The destination S3 URI for workflow outputs.
-
#parameters ⇒ Hash, ...
Workflow parameter names and values shared across all runs.
-
#priority ⇒ Integer
An integer priority for the workflow runs.
-
#retention_mode ⇒ String
The retention behavior for runs after completion.
-
#role_arn ⇒ String
The IAM role ARN that grants HealthOmics permissions to access required AWS resources such as Amazon S3 and CloudWatch.
-
#run_group_id ⇒ String
The ID of the run group to contain all workflow runs in the batch.
-
#run_tags ⇒ Hash<String,String>
AWS tags to associate with each workflow run.
-
#scratch_storage_mode ⇒ String
Optional configuration for enabling scratch ephemeral storage mounted at /tmp.
-
#storage_capacity ⇒ Integer
The filesystem size in gibibytes (GiB) provisioned for each workflow run and shared by all tasks in that run.
-
#storage_type ⇒ String
The storage type for the workflow runs.
-
#workflow_id ⇒ String
The identifier of the workflow to run.
-
#workflow_owner_id ⇒ String
The AWS account ID of the workflow owner, used for cross-account workflow sharing.
-
#workflow_type ⇒ String
The type of the originating workflow.
-
#workflow_version_name ⇒ String
The version name of the specified workflow.
Instance Attribute Details
#cache_behavior ⇒ String
The cache behavior for the runs. Requires ‘cacheId` to be set.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#cache_id ⇒ String
The identifier of the run cache to associate with the runs.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#configuration_name ⇒ String
Optional configuration name to use for the workflow run.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#engine_settings ⇒ Hash, ...
Engine-specific settings for the workflow run. Use this field to specify configuration options that are specific to the workflow engine (for example, Nextflow profiles).
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#log_level ⇒ String
The verbosity level for CloudWatch Logs emitted during each run.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
An optional user-friendly name applied to each workflow run. Can be overridden per run.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#networking_mode ⇒ String
Optional configuration for run networking behavior. If not specified, this will default to RESTRICTED.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#output_bucket_owner_id ⇒ String
The expected AWS account ID of the owner of the output S3 bucket. Can be overridden per run.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#output_uri ⇒ String
The destination S3 URI for workflow outputs. Must begin with ‘s3://`. The `roleArn` must grant write permissions to this bucket. Can be overridden per run.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash, ...
Workflow parameter names and values shared across all runs. Merged with per-run parameters; run-specific values take precedence when keys overlap. Can be overridden per run.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
An integer priority for the workflow runs. Higher values correspond to higher priority. A value of 0 corresponds to the lowest priority. Can be overridden per run.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#retention_mode ⇒ String
The retention behavior for runs after completion.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The IAM role ARN that grants HealthOmics permissions to access required AWS resources such as Amazon S3 and CloudWatch. The role must have the same permissions required for individual ‘StartRun` calls.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#run_group_id ⇒ String
The ID of the run group to contain all workflow runs in the batch.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#run_tags ⇒ Hash<String,String>
AWS tags to associate with each workflow run. Merged with per-run ‘runTags`; run-specific values take precedence when keys overlap.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#scratch_storage_mode ⇒ String
Optional configuration for enabling scratch ephemeral storage mounted at /tmp. If not specified, this will default to SHARED. This configuration is applicable only for CPU tasks. For tasks using GPUs, scratch storage is always LOCAL.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#storage_capacity ⇒ Integer
The filesystem size in gibibytes (GiB) provisioned for each workflow run and shared by all tasks in that run. Defaults to 1200 GiB if not specified.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
The storage type for the workflow runs.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#workflow_id ⇒ String
The identifier of the workflow to run.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#workflow_owner_id ⇒ String
The AWS account ID of the workflow owner, used for cross-account workflow sharing.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#workflow_type ⇒ String
The type of the originating workflow. Batch runs are not supported with ‘READY2RUN` workflows.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |
#workflow_version_name ⇒ String
The version name of the specified workflow.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-omics/types.rb', line 2152 class DefaultRunSetting < Struct.new( :workflow_id, :workflow_type, :role_arn, :name, :cache_id, :cache_behavior, :run_group_id, :priority, :parameters, :storage_capacity, :output_uri, :log_level, :run_tags, :retention_mode, :storage_type, :workflow_owner_id, :output_bucket_owner_id, :workflow_version_name, :networking_mode, :configuration_name, :engine_settings, :scratch_storage_mode) SENSITIVE = [] include Aws::Structure end |