Class: Aws::Omics::Types::GetBatchResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::GetBatchResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The unique ARN of the run batch.
-
#creation_time ⇒ Time
The timestamp when the batch was created.
-
#default_run_setting ⇒ Types::DefaultRunSetting
The shared configuration applied to all runs in the batch.
-
#failed_time ⇒ Time
The timestamp when the batch transitioned to a ‘FAILED` status.
-
#failure_reason ⇒ String
A description of the batch failure.
-
#id ⇒ String
The identifier portion of the run batch ARN.
-
#name ⇒ String
The optional user-friendly name of the batch.
-
#processed_time ⇒ Time
The timestamp when all run executions completed.
-
#run_summary ⇒ Types::RunSummary
A summary of run execution states.
-
#status ⇒ String
The current status of the run batch.
-
#submission_summary ⇒ Types::SubmissionSummary
A summary of run submission outcomes.
-
#submitted_time ⇒ Time
The timestamp when all run submissions completed.
-
#tags ⇒ Hash<String,String>
AWS tags associated with the run batch.
-
#total_runs ⇒ Integer
The total number of runs in the batch.
-
#uuid ⇒ String
The universally unique identifier (UUID) for the run batch.
Instance Attribute Details
#arn ⇒ String
The unique ARN of the run batch.
3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-omics/types.rb', line 3097 class GetBatchResponse < Struct.new( :id, :arn, :uuid, :name, :status, :tags, :total_runs, :default_run_setting, :submission_summary, :run_summary, :creation_time, :submitted_time, :processed_time, :failed_time, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp when the batch was created.
3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-omics/types.rb', line 3097 class GetBatchResponse < Struct.new( :id, :arn, :uuid, :name, :status, :tags, :total_runs, :default_run_setting, :submission_summary, :run_summary, :creation_time, :submitted_time, :processed_time, :failed_time, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#default_run_setting ⇒ Types::DefaultRunSetting
The shared configuration applied to all runs in the batch. See ‘DefaultRunSetting`.
3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-omics/types.rb', line 3097 class GetBatchResponse < Struct.new( :id, :arn, :uuid, :name, :status, :tags, :total_runs, :default_run_setting, :submission_summary, :run_summary, :creation_time, :submitted_time, :processed_time, :failed_time, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#failed_time ⇒ Time
The timestamp when the batch transitioned to a ‘FAILED` status.
3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-omics/types.rb', line 3097 class GetBatchResponse < Struct.new( :id, :arn, :uuid, :name, :status, :tags, :total_runs, :default_run_setting, :submission_summary, :run_summary, :creation_time, :submitted_time, :processed_time, :failed_time, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
A description of the batch failure. Present only when status is ‘FAILED`.
3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-omics/types.rb', line 3097 class GetBatchResponse < Struct.new( :id, :arn, :uuid, :name, :status, :tags, :total_runs, :default_run_setting, :submission_summary, :run_summary, :creation_time, :submitted_time, :processed_time, :failed_time, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier portion of the run batch ARN.
3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-omics/types.rb', line 3097 class GetBatchResponse < Struct.new( :id, :arn, :uuid, :name, :status, :tags, :total_runs, :default_run_setting, :submission_summary, :run_summary, :creation_time, :submitted_time, :processed_time, :failed_time, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The optional user-friendly name of the batch.
3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-omics/types.rb', line 3097 class GetBatchResponse < Struct.new( :id, :arn, :uuid, :name, :status, :tags, :total_runs, :default_run_setting, :submission_summary, :run_summary, :creation_time, :submitted_time, :processed_time, :failed_time, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#processed_time ⇒ Time
The timestamp when all run executions completed.
3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-omics/types.rb', line 3097 class GetBatchResponse < Struct.new( :id, :arn, :uuid, :name, :status, :tags, :total_runs, :default_run_setting, :submission_summary, :run_summary, :creation_time, :submitted_time, :processed_time, :failed_time, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#run_summary ⇒ Types::RunSummary
A summary of run execution states. Run execution counts are eventually consistent and may lag behind actual run states. Final counts are accurate once the batch reaches ‘PROCESSED` status. See `RunSummary`.
3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-omics/types.rb', line 3097 class GetBatchResponse < Struct.new( :id, :arn, :uuid, :name, :status, :tags, :total_runs, :default_run_setting, :submission_summary, :run_summary, :creation_time, :submitted_time, :processed_time, :failed_time, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the run batch. Possible values: ‘CREATING` (initial setup), `PENDING` (ready to submit runs), `SUBMITTING` (submitting runs), `INPROGRESS` (runs executing), `STOPPING` (cancellation in progress), `PROCESSED` (all runs completed), `CANCELLED` (batch cancelled), `FAILED` (batch failed), `RUNS_DELETING` (deleting runs), `RUNS_DELETED` (runs deleted).
3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-omics/types.rb', line 3097 class GetBatchResponse < Struct.new( :id, :arn, :uuid, :name, :status, :tags, :total_runs, :default_run_setting, :submission_summary, :run_summary, :creation_time, :submitted_time, :processed_time, :failed_time, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#submission_summary ⇒ Types::SubmissionSummary
A summary of run submission outcomes. See ‘SubmissionSummary`.
3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-omics/types.rb', line 3097 class GetBatchResponse < Struct.new( :id, :arn, :uuid, :name, :status, :tags, :total_runs, :default_run_setting, :submission_summary, :run_summary, :creation_time, :submitted_time, :processed_time, :failed_time, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#submitted_time ⇒ Time
The timestamp when all run submissions completed.
3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-omics/types.rb', line 3097 class GetBatchResponse < Struct.new( :id, :arn, :uuid, :name, :status, :tags, :total_runs, :default_run_setting, :submission_summary, :run_summary, :creation_time, :submitted_time, :processed_time, :failed_time, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
AWS tags associated with the run batch.
3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-omics/types.rb', line 3097 class GetBatchResponse < Struct.new( :id, :arn, :uuid, :name, :status, :tags, :total_runs, :default_run_setting, :submission_summary, :run_summary, :creation_time, :submitted_time, :processed_time, :failed_time, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#total_runs ⇒ Integer
The total number of runs in the batch.
3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-omics/types.rb', line 3097 class GetBatchResponse < Struct.new( :id, :arn, :uuid, :name, :status, :tags, :total_runs, :default_run_setting, :submission_summary, :run_summary, :creation_time, :submitted_time, :processed_time, :failed_time, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#uuid ⇒ String
The universally unique identifier (UUID) for the run batch.
3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-omics/types.rb', line 3097 class GetBatchResponse < Struct.new( :id, :arn, :uuid, :name, :status, :tags, :total_runs, :default_run_setting, :submission_summary, :run_summary, :creation_time, :submitted_time, :processed_time, :failed_time, :failure_reason) SENSITIVE = [] include Aws::Structure end |