Class: Aws::Omics::Types::GetRunResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::GetRunResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accelerators ⇒ String
The computational accelerator used to run the workflow.
-
#arn ⇒ String
The run’s ARN.
-
#batch_id ⇒ String
The run’s batch ID.
-
#cache_behavior ⇒ String
The run cache behavior for the run.
-
#cache_id ⇒ String
The run cache associated with the run.
-
#configuration ⇒ Types::ConfigurationDetails
Configuration details for the workflow run.
-
#creation_time ⇒ Time
When the run was created.
-
#definition ⇒ String
The run’s definition.
-
#digest ⇒ String
The run’s digest.
-
#engine_settings ⇒ Hash, ...
The engine-specific settings for the workflow run.
-
#engine_version ⇒ String
The actual Nextflow engine version that Amazon Web Services HealthOmics used for the run.
-
#failure_reason ⇒ String
The reason a run has failed.
-
#id ⇒ String
The run’s ID.
-
#log_level ⇒ String
The run’s log level.
-
#log_location ⇒ Types::RunLogLocation
The location of the run log.
-
#name ⇒ String
The run’s name.
-
#networking_mode ⇒ String
Configuration for run networking behavior.
-
#output_uri ⇒ String
The run’s output URI.
-
#parameters ⇒ Hash, ...
The run’s parameters.
-
#priority ⇒ Integer
The run’s priority.
-
#resource_digests ⇒ Hash<String,String>
The run’s resource digests.
-
#retention_mode ⇒ String
The run’s retention mode.
-
#role_arn ⇒ String
The run’s service role ARN.
-
#run_group_id ⇒ String
The run’s group ID.
-
#run_id ⇒ String
The run’s ID.
-
#run_output_uri ⇒ String
The destination for workflow outputs.
-
#scratch_storage_mode ⇒ String
Optional configuration for enabling scratch ephemeral storage mounted at /tmp.
-
#start_time ⇒ Time
When the run started.
-
#started_by ⇒ String
Who started the run.
-
#status ⇒ String
The run’s status.
-
#status_message ⇒ String
The run’s status message.
-
#stop_time ⇒ Time
The run’s stop time.
-
#storage_capacity ⇒ Integer
The run’s storage capacity in gibibytes.
-
#storage_type ⇒ String
The run’s storage type.
-
#tags ⇒ Hash<String,String>
The run’s tags.
-
#uuid ⇒ String
The universally unique identifier for a run.
-
#vpc_config ⇒ Types::VpcConfigResponse
VPC configuration for the workflow run.
-
#workflow_id ⇒ String
The run’s workflow ID.
-
#workflow_owner_id ⇒ String
The ID of the workflow owner.
-
#workflow_type ⇒ String
The run’s workflow type.
-
#workflow_uuid ⇒ String
The universally unique identifier (UUID) value for the workflow.
-
#workflow_version_name ⇒ String
The workflow version name.
Instance Attribute Details
#accelerators ⇒ String
The computational accelerator used to run the workflow.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The run’s ARN.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#batch_id ⇒ String
The run’s batch ID.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#cache_behavior ⇒ String
The run cache behavior for the run.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#cache_id ⇒ String
The run cache associated with the run.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::ConfigurationDetails
Configuration details for the workflow run.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the run was created.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#definition ⇒ String
The run’s definition.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#digest ⇒ String
The run’s digest.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#engine_settings ⇒ Hash, ...
The engine-specific settings for the workflow run.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The actual Nextflow engine version that Amazon Web Services HealthOmics used for the run. The other workflow definition languages don’t provide a value for this field.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reason a run has failed.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The run’s ID.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#log_level ⇒ String
The run’s log level.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#log_location ⇒ Types::RunLogLocation
The location of the run log.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The run’s name.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#networking_mode ⇒ String
Configuration for run networking behavior. If absent, this will default to RESTRICTED.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#output_uri ⇒ String
The run’s output URI.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash, ...
The run’s parameters.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
The run’s priority.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#resource_digests ⇒ Hash<String,String>
The run’s resource digests.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#retention_mode ⇒ String
The run’s retention mode.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The run’s service role ARN.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#run_group_id ⇒ String
The run’s group ID.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#run_id ⇒ String
The run’s ID.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#run_output_uri ⇒ String
The destination for workflow outputs.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#scratch_storage_mode ⇒ String
Optional configuration for enabling scratch ephemeral storage mounted at /tmp. If absent, this will default to SHARED. This configuration is applicable only for CPU tasks. For tasks using GPUs, scratch storage is always LOCAL.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
When the run started.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#started_by ⇒ String
Who started the run.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The run’s status.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The run’s status message.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#stop_time ⇒ Time
The run’s stop time.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#storage_capacity ⇒ Integer
The run’s storage capacity in gibibytes. For dynamic storage, after the run has completed, this value is the maximum amount of storage used during the run.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
The run’s storage type.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The run’s tags.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#uuid ⇒ String
The universally unique identifier for a run.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfigResponse
VPC configuration for the workflow run.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#workflow_id ⇒ String
The run’s workflow ID.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#workflow_owner_id ⇒ String
The ID of the workflow owner.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#workflow_type ⇒ String
The run’s workflow type.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#workflow_uuid ⇒ String
The universally unique identifier (UUID) value for the workflow.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |
#workflow_version_name ⇒ String
The workflow version name.
4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-omics/types.rb', line 4097 class GetRunResponse < Struct.new( :arn, :id, :cache_id, :cache_behavior, :engine_version, :status, :workflow_id, :workflow_type, :run_id, :role_arn, :name, :run_group_id, :batch_id, :priority, :definition, :digest, :parameters, :storage_capacity, :output_uri, :log_level, :resource_digests, :started_by, :creation_time, :start_time, :stop_time, :status_message, :tags, :accelerators, :retention_mode, :failure_reason, :log_location, :uuid, :run_output_uri, :storage_type, :workflow_owner_id, :workflow_version_name, :workflow_uuid, :networking_mode, :scratch_storage_mode, :configuration, :vpc_config, :engine_settings) SENSITIVE = [] include Aws::Structure end |