Class: Aws::Omics::Types::GetSequenceStoreResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::GetSequenceStoreResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The store’s ARN.
-
#creation_time ⇒ Time
When the store was created.
-
#description ⇒ String
The store’s description.
-
#e_tag_algorithm_family ⇒ String
The algorithm family of the ETag.
-
#fallback_location ⇒ String
An S3 location that is used to store files that have failed a direct upload.
-
#id ⇒ String
The store’s ID.
-
#name ⇒ String
The store’s name.
-
#propagated_set_level_tags ⇒ Array<String>
The tags keys to propagate to the S3 objects associated with read sets in the sequence store.
-
#s3_access ⇒ Types::SequenceStoreS3Access
The S3 metadata of a sequence store, including the ARN and S3 URI of the S3 bucket.
-
#sse_config ⇒ Types::SseConfig
The store’s server-side encryption (SSE) settings.
-
#status ⇒ String
The status of the sequence store.
-
#status_message ⇒ String
The status message of the sequence store.
-
#update_time ⇒ Time
The last-updated time of the sequence store.
Instance Attribute Details
#arn ⇒ String
The store’s ARN.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 |
# File 'lib/aws-sdk-omics/types.rb', line 4363 class GetSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :s3_access, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :update_time) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the store was created.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 |
# File 'lib/aws-sdk-omics/types.rb', line 4363 class GetSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :s3_access, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :update_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The store’s description.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 |
# File 'lib/aws-sdk-omics/types.rb', line 4363 class GetSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :s3_access, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :update_time) SENSITIVE = [] include Aws::Structure end |
#e_tag_algorithm_family ⇒ String
The algorithm family of the ETag.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 |
# File 'lib/aws-sdk-omics/types.rb', line 4363 class GetSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :s3_access, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :update_time) SENSITIVE = [] include Aws::Structure end |
#fallback_location ⇒ String
An S3 location that is used to store files that have failed a direct upload.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 |
# File 'lib/aws-sdk-omics/types.rb', line 4363 class GetSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :s3_access, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :update_time) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The store’s ID.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 |
# File 'lib/aws-sdk-omics/types.rb', line 4363 class GetSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :s3_access, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :update_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The store’s name.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 |
# File 'lib/aws-sdk-omics/types.rb', line 4363 class GetSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :s3_access, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :update_time) SENSITIVE = [] include Aws::Structure end |
#propagated_set_level_tags ⇒ Array<String>
The tags keys to propagate to the S3 objects associated with read sets in the sequence store.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 |
# File 'lib/aws-sdk-omics/types.rb', line 4363 class GetSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :s3_access, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :update_time) SENSITIVE = [] include Aws::Structure end |
#s3_access ⇒ Types::SequenceStoreS3Access
The S3 metadata of a sequence store, including the ARN and S3 URI of the S3 bucket.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 |
# File 'lib/aws-sdk-omics/types.rb', line 4363 class GetSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :s3_access, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :update_time) SENSITIVE = [] include Aws::Structure end |
#sse_config ⇒ Types::SseConfig
The store’s server-side encryption (SSE) settings.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 |
# File 'lib/aws-sdk-omics/types.rb', line 4363 class GetSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :s3_access, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :update_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the sequence store.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 |
# File 'lib/aws-sdk-omics/types.rb', line 4363 class GetSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :s3_access, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :update_time) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The status message of the sequence store.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 |
# File 'lib/aws-sdk-omics/types.rb', line 4363 class GetSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :s3_access, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :update_time) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The last-updated time of the sequence store.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 |
# File 'lib/aws-sdk-omics/types.rb', line 4363 class GetSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :fallback_location, :s3_access, :e_tag_algorithm_family, :status, :status_message, :propagated_set_level_tags, :update_time) SENSITIVE = [] include Aws::Structure end |