Class: Aws::Omics::Types::GetWorkflowResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-omics/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acceleratorsString

The computational accelerator specified to run the workflow.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The workflow’s ARN.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#container_registry_mapTypes::ContainerRegistryMap

The registry map that this workflow is using.



4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

When the workflow was created.

Returns:

  • (Time)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#definitionString

The workflow’s definition.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#definition_repository_detailsTypes::DefinitionRepositoryDetails

Details about the source code repository that hosts the workflow definition files.



4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The workflow’s description.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#digestString

The workflow’s digest.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#engineString

The workflow’s engine.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The workflow’s ID.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#mainString

The path of the main definition file for the workflow.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#metadataHash<String,String>

Gets metadata for the workflow.

Returns:

  • (Hash<String,String>)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The workflow’s name.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_templateHash<String,Types::WorkflowParameter>

The workflow’s parameter template.

Returns:



4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#readmeString

The README content for the workflow, providing documentation and usage information.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#readme_pathString

The path to the workflow README markdown file within the repository. This file provides documentation and usage information for the workflow. If not specified, the ‘README.md` file from the root directory of the repository will be used.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The workflow’s status.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

The workflow’s status message.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#storage_capacityInteger

The default static storage capacity (in gibibytes) for runs that use this workflow or workflow version.

Returns:

  • (Integer)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The default storage type for runs using this workflow.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The workflow’s tags.

Returns:

  • (Hash<String,String>)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The workflow’s type.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#uuidString

The universally unique identifier (UUID) value for this workflow.

Returns:

  • (String)


4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
# File 'lib/aws-sdk-omics/types.rb', line 4658

class GetWorkflowResponse < Struct.new(
  :arn,
  :id,
  :status,
  :type,
  :name,
  :description,
  :engine,
  :definition,
  :main,
  :digest,
  :parameter_template,
  :storage_capacity,
  :creation_time,
  :status_message,
  :tags,
  :metadata,
  :accelerators,
  :storage_type,
  :uuid,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end