Class: Aws::Omics::Types::GetWorkflowVersionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-omics/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acceleratorsString

The accelerator for this workflow version.

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

ARN of the workflow version.

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#container_registry_mapTypes::ContainerRegistryMap

The registry map that this workflow version uses.



4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

When the workflow version was created.

Returns:

  • (Time)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#definitionString

Definition of the workflow version.

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#definition_repository_detailsTypes::DefinitionRepositoryDetails

Details about the source code repository that hosts the workflow version definition files.



4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Description of the workflow version.

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#digestString

The workflow version’s digest.

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#engineString

The workflow engine for this workflow version.

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#mainString

The path of the main definition file for the workflow.

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#metadataHash<String,String>

The metadata for the workflow version.

Returns:

  • (Hash<String,String>)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_templateHash<String,Types::WorkflowParameter>

The parameter template for the workflow version.

Returns:



4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#profile_parameter_templatesHash<String,Hash<String,Types::WorkflowParameter>>

A mapping of profile names to their parameter templates. Each profile defines its own set of parameters that you can use when starting a run with that profile.

Returns:



4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#profilesArray<String>

The list of Nextflow profiles that are available for this workflow version. Profiles allow you to select predefined configuration settings at runtime.

Returns:

  • (Array<String>)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#readmeString

The README content for the workflow version, providing documentation and usage information specific to this version.

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#readme_pathString

The path to the workflow version README markdown file within the repository. This file provides documentation and usage information for the workflow. If not specified, the ‘README.md` file from the root directory of the repository will be used.

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The workflow version status

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

The workflow version status message

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#storage_capacityInteger

The default run storage capacity for static storage.

Returns:

  • (Integer)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The default storage type for the run.

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The workflow version tags

Returns:

  • (Hash<String,String>)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The workflow version type

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#uuidString

The universally unique identifier (UUID) value for this workflow version

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#version_nameString

The workflow version name.

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_bucket_owner_idString

Amazon Web Services Id of the owner of the bucket.

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_idString

The workflow’s ID.

Returns:

  • (String)


4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-omics/types.rb', line 4878

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path,
  :profiles,
  :profile_parameter_templates)
  SENSITIVE = []
  include Aws::Structure
end