Class: Aws::Omics::Types::GetWorkflowVersionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::GetWorkflowVersionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accelerators ⇒ String
The accelerator for this workflow version.
-
#arn ⇒ String
ARN of the workflow version.
-
#container_registry_map ⇒ Types::ContainerRegistryMap
The registry map that this workflow version uses.
-
#creation_time ⇒ Time
When the workflow version was created.
-
#definition ⇒ String
Definition of the workflow version.
-
#definition_repository_details ⇒ Types::DefinitionRepositoryDetails
Details about the source code repository that hosts the workflow version definition files.
-
#description ⇒ String
Description of the workflow version.
-
#digest ⇒ String
The workflow version’s digest.
-
#engine ⇒ String
The workflow engine for this workflow version.
-
#main ⇒ String
The path of the main definition file for the workflow.
-
#metadata ⇒ Hash<String,String>
The metadata for the workflow version.
-
#parameter_template ⇒ Hash<String,Types::WorkflowParameter>
The parameter template for the workflow version.
-
#profile_parameter_templates ⇒ Hash<String,Hash<String,Types::WorkflowParameter>>
A mapping of profile names to their parameter templates.
-
#profiles ⇒ Array<String>
The list of Nextflow profiles that are available for this workflow version.
-
#readme ⇒ String
The README content for the workflow version, providing documentation and usage information specific to this version.
-
#readme_path ⇒ String
The path to the workflow version README markdown file within the repository.
-
#status ⇒ String
The workflow version status.
-
#status_message ⇒ String
The workflow version status message.
-
#storage_capacity ⇒ Integer
The default run storage capacity for static storage.
-
#storage_type ⇒ String
The default storage type for the run.
-
#tags ⇒ Hash<String,String>
The workflow version tags.
-
#type ⇒ String
The workflow version type.
-
#uuid ⇒ String
The universally unique identifier (UUID) value for this workflow version.
-
#version_name ⇒ String
The workflow version name.
-
#workflow_bucket_owner_id ⇒ String
Amazon Web Services Id of the owner of the bucket.
-
#workflow_id ⇒ String
The workflow’s ID.
Instance Attribute Details
#accelerators ⇒ String
The accelerator for this workflow version.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
ARN of the workflow version.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#container_registry_map ⇒ Types::ContainerRegistryMap
The registry map that this workflow version uses.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the workflow version was created.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#definition ⇒ String
Definition of the workflow version.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#definition_repository_details ⇒ Types::DefinitionRepositoryDetails
Details about the source code repository that hosts the workflow version definition files.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Description of the workflow version.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#digest ⇒ String
The workflow version’s digest.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The workflow engine for this workflow version.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#main ⇒ String
The path of the main definition file for the workflow.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Hash<String,String>
The metadata for the workflow version.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#parameter_template ⇒ Hash<String,Types::WorkflowParameter>
The parameter template for the workflow version.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#profile_parameter_templates ⇒ Hash<String,Hash<String,Types::WorkflowParameter>>
A mapping of profile names to their parameter templates. Each profile defines its own set of parameters that you can use when starting a run with that profile.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#profiles ⇒ Array<String>
The list of Nextflow profiles that are available for this workflow version. Profiles allow you to select predefined configuration settings at runtime.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#readme ⇒ String
The README content for the workflow version, providing documentation and usage information specific to this version.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#readme_path ⇒ String
The path to the workflow version README markdown file within the repository. This file provides documentation and usage information for the workflow. If not specified, the ‘README.md` file from the root directory of the repository will be used.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The workflow version status
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The workflow version status message
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#storage_capacity ⇒ Integer
The default run storage capacity for static storage.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
The default storage type for the run.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The workflow version tags
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The workflow version type
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#uuid ⇒ String
The universally unique identifier (UUID) value for this workflow version
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#version_name ⇒ String
The workflow version name.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#workflow_bucket_owner_id ⇒ String
Amazon Web Services Id of the owner of the bucket.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |
#workflow_id ⇒ String
The workflow’s ID.
4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-omics/types.rb', line 4862 class GetWorkflowVersionResponse < Struct.new( :arn, :workflow_id, :version_name, :accelerators, :creation_time, :description, :definition, :digest, :engine, :main, :metadata, :parameter_template, :status, :status_message, :storage_type, :storage_capacity, :type, :tags, :uuid, :workflow_bucket_owner_id, :container_registry_map, :readme, :definition_repository_details, :readme_path, :profiles, :profile_parameter_templates) SENSITIVE = [] include Aws::Structure end |