Class: Aws::Omics::Types::GetWorkflowVersionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-omics/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acceleratorsString

The accelerator for this workflow version.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

ARN of the workflow version.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#container_registry_mapTypes::ContainerRegistryMap

The registry map that this workflow version uses.



4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

When the workflow version was created.

Returns:

  • (Time)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#definitionString

Definition of the workflow version.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#definition_repository_detailsTypes::DefinitionRepositoryDetails

Details about the source code repository that hosts the workflow version definition files.



4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Description of the workflow version.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#digestString

The workflow version’s digest.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#engineString

The workflow engine for this workflow version.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#mainString

The path of the main definition file for the workflow.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#metadataHash<String,String>

The metadata for the workflow version.

Returns:

  • (Hash<String,String>)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_templateHash<String,Types::WorkflowParameter>

The parameter template for the workflow version.

Returns:



4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#readmeString

The README content for the workflow version, providing documentation and usage information specific to this version.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#readme_pathString

The path to the workflow version README markdown file within the repository. This file provides documentation and usage information for the workflow. If not specified, the ‘README.md` file from the root directory of the repository will be used.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The workflow version status

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

The workflow version status message

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#storage_capacityInteger

The default run storage capacity for static storage.

Returns:

  • (Integer)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The default storage type for the run.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The workflow version tags

Returns:

  • (Hash<String,String>)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The workflow version type

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#uuidString

The universally unique identifier (UUID) value for this workflow version

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#version_nameString

The workflow version name.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_bucket_owner_idString

Amazon Web Services Id of the owner of the bucket.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_idString

The workflow’s ID.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-omics/types.rb', line 4824

class GetWorkflowVersionResponse < Struct.new(
  :arn,
  :workflow_id,
  :version_name,
  :accelerators,
  :creation_time,
  :description,
  :definition,
  :digest,
  :engine,
  :main,
  :metadata,
  :parameter_template,
  :status,
  :status_message,
  :storage_type,
  :storage_capacity,
  :type,
  :tags,
  :uuid,
  :workflow_bucket_owner_id,
  :container_registry_map,
  :readme,
  :definition_repository_details,
  :readme_path)
  SENSITIVE = []
  include Aws::Structure
end