Class: Aws::Omics::Types::ImageMapping

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-omics/types.rb

Overview

Specifies image mappings that workflow tasks can use. For example, you can replace all the task references of a public image to use an equivalent image in your private ECR repository. You can use image mappings with upstream registries that don’t support pull through cache. You need to manually synchronize the upstream registry with your private repository.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_imageString

Specifies the URI of the corresponding image in the private ECR registry.

Returns:

  • (String)


4899
4900
4901
4902
4903
4904
# File 'lib/aws-sdk-omics/types.rb', line 4899

class ImageMapping < Struct.new(
  :source_image,
  :destination_image)
  SENSITIVE = []
  include Aws::Structure
end

#source_imageString

Specifies the URI of the source image in the upstream registry.

Returns:

  • (String)


4899
4900
4901
4902
4903
4904
# File 'lib/aws-sdk-omics/types.rb', line 4899

class ImageMapping < Struct.new(
  :source_image,
  :destination_image)
  SENSITIVE = []
  include Aws::Structure
end