Class: Aws::Omics::Types::InlineSetting

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-omics/types.rb

Overview

A per-run configuration that overrides or merges with fields from ‘DefaultRunSetting` for a specific run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

An optional user-friendly name for this run.

Returns:

  • (String)


5184
5185
5186
5187
5188
5189
5190
5191
5192
5193
5194
# File 'lib/aws-sdk-omics/types.rb', line 5184

class InlineSetting < Struct.new(
  :run_setting_id,
  :name,
  :output_uri,
  :priority,
  :parameters,
  :output_bucket_owner_id,
  :run_tags)
  SENSITIVE = []
  include Aws::Structure
end

#output_bucket_owner_idString

The expected AWS account ID of the owner of the output S3 bucket for this run.

Returns:

  • (String)


5184
5185
5186
5187
5188
5189
5190
5191
5192
5193
5194
# File 'lib/aws-sdk-omics/types.rb', line 5184

class InlineSetting < Struct.new(
  :run_setting_id,
  :name,
  :output_uri,
  :priority,
  :parameters,
  :output_bucket_owner_id,
  :run_tags)
  SENSITIVE = []
  include Aws::Structure
end

#output_uriString

Override the destination S3 URI for this run’s outputs.

Returns:

  • (String)


5184
5185
5186
5187
5188
5189
5190
5191
5192
5193
5194
# File 'lib/aws-sdk-omics/types.rb', line 5184

class InlineSetting < Struct.new(
  :run_setting_id,
  :name,
  :output_uri,
  :priority,
  :parameters,
  :output_bucket_owner_id,
  :run_tags)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash, ...

Per-run workflow parameters. Merged with ‘defaultRunSetting.parameters`; values in this object take precedence when keys overlap.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


5184
5185
5186
5187
5188
5189
5190
5191
5192
5193
5194
# File 'lib/aws-sdk-omics/types.rb', line 5184

class InlineSetting < Struct.new(
  :run_setting_id,
  :name,
  :output_uri,
  :priority,
  :parameters,
  :output_bucket_owner_id,
  :run_tags)
  SENSITIVE = []
  include Aws::Structure
end

#priorityInteger

Override the priority for this run.

Returns:

  • (Integer)


5184
5185
5186
5187
5188
5189
5190
5191
5192
5193
5194
# File 'lib/aws-sdk-omics/types.rb', line 5184

class InlineSetting < Struct.new(
  :run_setting_id,
  :name,
  :output_uri,
  :priority,
  :parameters,
  :output_bucket_owner_id,
  :run_tags)
  SENSITIVE = []
  include Aws::Structure
end

#run_setting_idString

A customer-provided unique identifier for this run configuration within the batch. After submission, use ‘ListRunsInBatch` to map each `runSettingId` to the HealthOmics-generated `runId`.

Returns:

  • (String)


5184
5185
5186
5187
5188
5189
5190
5191
5192
5193
5194
# File 'lib/aws-sdk-omics/types.rb', line 5184

class InlineSetting < Struct.new(
  :run_setting_id,
  :name,
  :output_uri,
  :priority,
  :parameters,
  :output_bucket_owner_id,
  :run_tags)
  SENSITIVE = []
  include Aws::Structure
end

#run_tagsHash<String,String>

Per-run AWS tags. Merged with ‘defaultRunSetting.runTags`; values in this object take precedence when keys overlap.

Returns:

  • (Hash<String,String>)


5184
5185
5186
5187
5188
5189
5190
5191
5192
5193
5194
# File 'lib/aws-sdk-omics/types.rb', line 5184

class InlineSetting < Struct.new(
  :run_setting_id,
  :name,
  :output_uri,
  :priority,
  :parameters,
  :output_bucket_owner_id,
  :run_tags)
  SENSITIVE = []
  include Aws::Structure
end