Class: Aws::Omics::Types::InlineSetting
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::InlineSetting
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
A per-run configuration that overrides or merges with fields from ‘DefaultRunSetting` for a specific run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
An optional user-friendly name for this run.
-
#output_bucket_owner_id ⇒ String
The expected AWS account ID of the owner of the output S3 bucket for this run.
-
#output_uri ⇒ String
Override the destination S3 URI for this run’s outputs.
-
#parameters ⇒ Hash, ...
Per-run workflow parameters.
-
#priority ⇒ Integer
Override the priority for this run.
-
#run_setting_id ⇒ String
A customer-provided unique identifier for this run configuration within the batch.
-
#run_tags ⇒ Hash<String,String>
Per-run AWS tags.
Instance Attribute Details
#name ⇒ String
An optional user-friendly name for this run.
5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 |
# File 'lib/aws-sdk-omics/types.rb', line 5184 class InlineSetting < Struct.new( :run_setting_id, :name, :output_uri, :priority, :parameters, :output_bucket_owner_id, :run_tags) SENSITIVE = [] include Aws::Structure end |
#output_bucket_owner_id ⇒ String
The expected AWS account ID of the owner of the output S3 bucket for this run.
5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 |
# File 'lib/aws-sdk-omics/types.rb', line 5184 class InlineSetting < Struct.new( :run_setting_id, :name, :output_uri, :priority, :parameters, :output_bucket_owner_id, :run_tags) SENSITIVE = [] include Aws::Structure end |
#output_uri ⇒ String
Override the destination S3 URI for this run’s outputs.
5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 |
# File 'lib/aws-sdk-omics/types.rb', line 5184 class InlineSetting < Struct.new( :run_setting_id, :name, :output_uri, :priority, :parameters, :output_bucket_owner_id, :run_tags) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash, ...
Per-run workflow parameters. Merged with ‘defaultRunSetting.parameters`; values in this object take precedence when keys overlap.
5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 |
# File 'lib/aws-sdk-omics/types.rb', line 5184 class InlineSetting < Struct.new( :run_setting_id, :name, :output_uri, :priority, :parameters, :output_bucket_owner_id, :run_tags) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
Override the priority for this run.
5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 |
# File 'lib/aws-sdk-omics/types.rb', line 5184 class InlineSetting < Struct.new( :run_setting_id, :name, :output_uri, :priority, :parameters, :output_bucket_owner_id, :run_tags) SENSITIVE = [] include Aws::Structure end |
#run_setting_id ⇒ String
A customer-provided unique identifier for this run configuration within the batch. After submission, use ‘ListRunsInBatch` to map each `runSettingId` to the HealthOmics-generated `runId`.
5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 |
# File 'lib/aws-sdk-omics/types.rb', line 5184 class InlineSetting < Struct.new( :run_setting_id, :name, :output_uri, :priority, :parameters, :output_bucket_owner_id, :run_tags) SENSITIVE = [] include Aws::Structure end |
#run_tags ⇒ Hash<String,String>
Per-run AWS tags. Merged with ‘defaultRunSetting.runTags`; values in this object take precedence when keys overlap.
5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 |
# File 'lib/aws-sdk-omics/types.rb', line 5184 class InlineSetting < Struct.new( :run_setting_id, :name, :output_uri, :priority, :parameters, :output_bucket_owner_id, :run_tags) SENSITIVE = [] include Aws::Structure end |