Class: Aws::Omics::Types::ListRunsInBatchResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::ListRunsInBatchResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A pagination token to retrieve the next page of results.
-
#runs ⇒ Array<Types::RunBatchListItem>
A list of run entries in the batch.
Instance Attribute Details
#next_token ⇒ String
A pagination token to retrieve the next page of results. Absent when the last run has been returned.
6046 6047 6048 6049 6050 6051 |
# File 'lib/aws-sdk-omics/types.rb', line 6046 class ListRunsInBatchResponse < Struct.new( :runs, :next_token) SENSITIVE = [] include Aws::Structure end |
#runs ⇒ Array<Types::RunBatchListItem>
A list of run entries in the batch. See RunBatchListItem.
6046 6047 6048 6049 6050 6051 |
# File 'lib/aws-sdk-omics/types.rb', line 6046 class ListRunsInBatchResponse < Struct.new( :runs, :next_token) SENSITIVE = [] include Aws::Structure end |