Class: Aws::Omics::Types::RegistryMapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::RegistryMapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
If you are using the ECR pull through cache feature, the registry mapping maps between the ECR repository and the upstream registry where container images are pulled and synchronized.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ecr_account_id ⇒ String
Account ID of the account that owns the upstream container image.
-
#ecr_repository_prefix ⇒ String
The repository prefix to use in the ECR private repository.
-
#upstream_registry_url ⇒ String
The URI of the upstream registry.
-
#upstream_repository_prefix ⇒ String
The repository prefix of the corresponding repository in the upstream registry.
Instance Attribute Details
#ecr_account_id ⇒ String
Account ID of the account that owns the upstream container image.
7181 7182 7183 7184 7185 7186 7187 7188 |
# File 'lib/aws-sdk-omics/types.rb', line 7181 class RegistryMapping < Struct.new( :upstream_registry_url, :ecr_repository_prefix, :upstream_repository_prefix, :ecr_account_id) SENSITIVE = [] include Aws::Structure end |
#ecr_repository_prefix ⇒ String
The repository prefix to use in the ECR private repository.
7181 7182 7183 7184 7185 7186 7187 7188 |
# File 'lib/aws-sdk-omics/types.rb', line 7181 class RegistryMapping < Struct.new( :upstream_registry_url, :ecr_repository_prefix, :upstream_repository_prefix, :ecr_account_id) SENSITIVE = [] include Aws::Structure end |
#upstream_registry_url ⇒ String
The URI of the upstream registry.
7181 7182 7183 7184 7185 7186 7187 7188 |
# File 'lib/aws-sdk-omics/types.rb', line 7181 class RegistryMapping < Struct.new( :upstream_registry_url, :ecr_repository_prefix, :upstream_repository_prefix, :ecr_account_id) SENSITIVE = [] include Aws::Structure end |
#upstream_repository_prefix ⇒ String
The repository prefix of the corresponding repository in the upstream registry.
7181 7182 7183 7184 7185 7186 7187 7188 |
# File 'lib/aws-sdk-omics/types.rb', line 7181 class RegistryMapping < Struct.new( :upstream_registry_url, :ecr_repository_prefix, :upstream_repository_prefix, :ecr_account_id) SENSITIVE = [] include Aws::Structure end |