Class: Aws::Omics::Types::RegistryMapping

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-omics/types.rb

Overview

If you are using the ECR pull through cache feature, the registry mapping maps between the ECR repository and the upstream registry where container images are pulled and synchronized.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ecr_account_idString

Account ID of the account that owns the upstream container image.

Returns:

  • (String)


7150
7151
7152
7153
7154
7155
7156
7157
# File 'lib/aws-sdk-omics/types.rb', line 7150

class RegistryMapping < Struct.new(
  :upstream_registry_url,
  :ecr_repository_prefix,
  :upstream_repository_prefix,
  :ecr_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#ecr_repository_prefixString

The repository prefix to use in the ECR private repository.

Returns:

  • (String)


7150
7151
7152
7153
7154
7155
7156
7157
# File 'lib/aws-sdk-omics/types.rb', line 7150

class RegistryMapping < Struct.new(
  :upstream_registry_url,
  :ecr_repository_prefix,
  :upstream_repository_prefix,
  :ecr_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#upstream_registry_urlString

The URI of the upstream registry.

Returns:

  • (String)


7150
7151
7152
7153
7154
7155
7156
7157
# File 'lib/aws-sdk-omics/types.rb', line 7150

class RegistryMapping < Struct.new(
  :upstream_registry_url,
  :ecr_repository_prefix,
  :upstream_repository_prefix,
  :ecr_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#upstream_repository_prefixString

The repository prefix of the corresponding repository in the upstream registry.

Returns:

  • (String)


7150
7151
7152
7153
7154
7155
7156
7157
# File 'lib/aws-sdk-omics/types.rb', line 7150

class RegistryMapping < Struct.new(
  :upstream_registry_url,
  :ecr_repository_prefix,
  :upstream_repository_prefix,
  :ecr_account_id)
  SENSITIVE = []
  include Aws::Structure
end