Class: Aws::Omics::Types::RunListItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::RunListItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
A workflow run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The run's ARN.
-
#batch_id ⇒ String
The run's batch ID.
-
#creation_time ⇒ Time
When the run was created.
-
#id ⇒ String
The run's ID.
-
#name ⇒ String
The run's name.
-
#priority ⇒ Integer
The run's priority.
-
#start_time ⇒ Time
When the run started.
-
#status ⇒ String
The run's status.
-
#stop_time ⇒ Time
When the run stopped.
-
#storage_capacity ⇒ Integer
The run's storage capacity in gibibytes.
-
#storage_type ⇒ String
The run's storage type.
-
#workflow_id ⇒ String
The run's workflow ID.
-
#workflow_name ⇒ String
The name of the workflow.
-
#workflow_version_name ⇒ String
The name of the workflow version.
Instance Attribute Details
#arn ⇒ String
The run's ARN.
7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/aws-sdk-omics/types.rb', line 7469 class RunListItem < Struct.new( :arn, :id, :status, :workflow_id, :batch_id, :name, :priority, :storage_capacity, :creation_time, :start_time, :stop_time, :storage_type, :workflow_version_name, :workflow_name) SENSITIVE = [] include Aws::Structure end |
#batch_id ⇒ String
The run's batch ID.
7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/aws-sdk-omics/types.rb', line 7469 class RunListItem < Struct.new( :arn, :id, :status, :workflow_id, :batch_id, :name, :priority, :storage_capacity, :creation_time, :start_time, :stop_time, :storage_type, :workflow_version_name, :workflow_name) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the run was created.
7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/aws-sdk-omics/types.rb', line 7469 class RunListItem < Struct.new( :arn, :id, :status, :workflow_id, :batch_id, :name, :priority, :storage_capacity, :creation_time, :start_time, :stop_time, :storage_type, :workflow_version_name, :workflow_name) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The run's ID.
7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/aws-sdk-omics/types.rb', line 7469 class RunListItem < Struct.new( :arn, :id, :status, :workflow_id, :batch_id, :name, :priority, :storage_capacity, :creation_time, :start_time, :stop_time, :storage_type, :workflow_version_name, :workflow_name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The run's name.
7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/aws-sdk-omics/types.rb', line 7469 class RunListItem < Struct.new( :arn, :id, :status, :workflow_id, :batch_id, :name, :priority, :storage_capacity, :creation_time, :start_time, :stop_time, :storage_type, :workflow_version_name, :workflow_name) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
The run's priority.
7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/aws-sdk-omics/types.rb', line 7469 class RunListItem < Struct.new( :arn, :id, :status, :workflow_id, :batch_id, :name, :priority, :storage_capacity, :creation_time, :start_time, :stop_time, :storage_type, :workflow_version_name, :workflow_name) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
When the run started.
7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/aws-sdk-omics/types.rb', line 7469 class RunListItem < Struct.new( :arn, :id, :status, :workflow_id, :batch_id, :name, :priority, :storage_capacity, :creation_time, :start_time, :stop_time, :storage_type, :workflow_version_name, :workflow_name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The run's status.
7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/aws-sdk-omics/types.rb', line 7469 class RunListItem < Struct.new( :arn, :id, :status, :workflow_id, :batch_id, :name, :priority, :storage_capacity, :creation_time, :start_time, :stop_time, :storage_type, :workflow_version_name, :workflow_name) SENSITIVE = [] include Aws::Structure end |
#stop_time ⇒ Time
When the run stopped.
7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/aws-sdk-omics/types.rb', line 7469 class RunListItem < Struct.new( :arn, :id, :status, :workflow_id, :batch_id, :name, :priority, :storage_capacity, :creation_time, :start_time, :stop_time, :storage_type, :workflow_version_name, :workflow_name) SENSITIVE = [] include Aws::Structure end |
#storage_capacity ⇒ Integer
The run's storage capacity in gibibytes. For dynamic storage, after the run has completed, this value is the maximum amount of storage used during the run.
7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/aws-sdk-omics/types.rb', line 7469 class RunListItem < Struct.new( :arn, :id, :status, :workflow_id, :batch_id, :name, :priority, :storage_capacity, :creation_time, :start_time, :stop_time, :storage_type, :workflow_version_name, :workflow_name) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
The run's storage type.
7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/aws-sdk-omics/types.rb', line 7469 class RunListItem < Struct.new( :arn, :id, :status, :workflow_id, :batch_id, :name, :priority, :storage_capacity, :creation_time, :start_time, :stop_time, :storage_type, :workflow_version_name, :workflow_name) SENSITIVE = [] include Aws::Structure end |
#workflow_id ⇒ String
The run's workflow ID.
7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/aws-sdk-omics/types.rb', line 7469 class RunListItem < Struct.new( :arn, :id, :status, :workflow_id, :batch_id, :name, :priority, :storage_capacity, :creation_time, :start_time, :stop_time, :storage_type, :workflow_version_name, :workflow_name) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of the workflow.
7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/aws-sdk-omics/types.rb', line 7469 class RunListItem < Struct.new( :arn, :id, :status, :workflow_id, :batch_id, :name, :priority, :storage_capacity, :creation_time, :start_time, :stop_time, :storage_type, :workflow_version_name, :workflow_name) SENSITIVE = [] include Aws::Structure end |
#workflow_version_name ⇒ String
The name of the workflow version.
7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/aws-sdk-omics/types.rb', line 7469 class RunListItem < Struct.new( :arn, :id, :status, :workflow_id, :batch_id, :name, :priority, :storage_capacity, :creation_time, :start_time, :stop_time, :storage_type, :workflow_version_name, :workflow_name) SENSITIVE = [] include Aws::Structure end |