Class: Aws::Omics::Types::StartRunBatchRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::StartRunBatchRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_name ⇒ String
An optional user-friendly name for the run batch.
-
#batch_run_settings ⇒ Types::BatchRunSettings
The individual run configurations.
-
#default_run_setting ⇒ Types::DefaultRunSetting
Shared configuration applied to all runs in the batch.
-
#request_id ⇒ String
A client token used to deduplicate retry requests and prevent duplicate batches from being created.
-
#tags ⇒ Hash<String,String>
AWS tags to associate with the batch resource.
Instance Attribute Details
#batch_name ⇒ String
An optional user-friendly name for the run batch.
8189 8190 8191 8192 8193 8194 8195 8196 8197 |
# File 'lib/aws-sdk-omics/types.rb', line 8189 class StartRunBatchRequest < Struct.new( :batch_name, :request_id, :tags, :default_run_setting, :batch_run_settings) SENSITIVE = [] include Aws::Structure end |
#batch_run_settings ⇒ Types::BatchRunSettings
The individual run configurations. Specify exactly one of ‘inlineSettings` or `s3UriSettings`. See `BatchRunSettings`.
8189 8190 8191 8192 8193 8194 8195 8196 8197 |
# File 'lib/aws-sdk-omics/types.rb', line 8189 class StartRunBatchRequest < Struct.new( :batch_name, :request_id, :tags, :default_run_setting, :batch_run_settings) SENSITIVE = [] include Aws::Structure end |
#default_run_setting ⇒ Types::DefaultRunSetting
Shared configuration applied to all runs in the batch. See ‘DefaultRunSetting`.
8189 8190 8191 8192 8193 8194 8195 8196 8197 |
# File 'lib/aws-sdk-omics/types.rb', line 8189 class StartRunBatchRequest < Struct.new( :batch_name, :request_id, :tags, :default_run_setting, :batch_run_settings) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
A client token used to deduplicate retry requests and prevent duplicate batches from being created.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
8189 8190 8191 8192 8193 8194 8195 8196 8197 |
# File 'lib/aws-sdk-omics/types.rb', line 8189 class StartRunBatchRequest < Struct.new( :batch_name, :request_id, :tags, :default_run_setting, :batch_run_settings) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
AWS tags to associate with the batch resource. These tags are not inherited by individual runs. To tag individual runs, use ‘defaultRunSetting.runTags`.
8189 8190 8191 8192 8193 8194 8195 8196 8197 |
# File 'lib/aws-sdk-omics/types.rb', line 8189 class StartRunBatchRequest < Struct.new( :batch_name, :request_id, :tags, :default_run_setting, :batch_run_settings) SENSITIVE = [] include Aws::Structure end |