Class: Aws::Omics::Types::UpdateSequenceStoreResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::UpdateSequenceStoreResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the sequence store.
-
#creation_time ⇒ Time
The time when the store was created.
-
#description ⇒ String
Description of the sequence store.
-
#e_tag_algorithm_family ⇒ String
The ETag algorithm family to use on ingested read sets.
-
#fallback_location ⇒ String
The S3 URI of a bucket and folder to store Read Sets that fail to upload.
-
#id ⇒ String
The ID of the sequence store.
-
#name ⇒ String
The name of the sequence store.
-
#propagated_set_level_tags ⇒ Array<String>
The tags keys to propagate to the S3 objects associated with read sets in the sequence store.
-
#s3_access ⇒ Types::SequenceStoreS3Access
The S3 access metadata of the sequence store.
-
#sse_config ⇒ Types::SseConfig
Server-side encryption (SSE) settings for a store.
-
#status ⇒ String
The status of the sequence store.
-
#status_message ⇒ String
The status message of the sequence store.
-
#update_time ⇒ Time
The last-updated time of the Sequence Store.
Instance Attribute Details
#arn ⇒ String
The ARN of the sequence store.
9086 9087 9088 9089 9090 9091 9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-omics/types.rb', line 9086 class UpdateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :update_time, :propagated_set_level_tags, :status, :status_message, :fallback_location, :s3_access, :e_tag_algorithm_family) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time when the store was created.
9086 9087 9088 9089 9090 9091 9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-omics/types.rb', line 9086 class UpdateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :update_time, :propagated_set_level_tags, :status, :status_message, :fallback_location, :s3_access, :e_tag_algorithm_family) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Description of the sequence store.
9086 9087 9088 9089 9090 9091 9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-omics/types.rb', line 9086 class UpdateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :update_time, :propagated_set_level_tags, :status, :status_message, :fallback_location, :s3_access, :e_tag_algorithm_family) SENSITIVE = [] include Aws::Structure end |
#e_tag_algorithm_family ⇒ String
The ETag algorithm family to use on ingested read sets.
9086 9087 9088 9089 9090 9091 9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-omics/types.rb', line 9086 class UpdateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :update_time, :propagated_set_level_tags, :status, :status_message, :fallback_location, :s3_access, :e_tag_algorithm_family) SENSITIVE = [] include Aws::Structure end |
#fallback_location ⇒ String
The S3 URI of a bucket and folder to store Read Sets that fail to upload.
9086 9087 9088 9089 9090 9091 9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-omics/types.rb', line 9086 class UpdateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :update_time, :propagated_set_level_tags, :status, :status_message, :fallback_location, :s3_access, :e_tag_algorithm_family) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the sequence store.
9086 9087 9088 9089 9090 9091 9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-omics/types.rb', line 9086 class UpdateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :update_time, :propagated_set_level_tags, :status, :status_message, :fallback_location, :s3_access, :e_tag_algorithm_family) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the sequence store.
9086 9087 9088 9089 9090 9091 9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-omics/types.rb', line 9086 class UpdateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :update_time, :propagated_set_level_tags, :status, :status_message, :fallback_location, :s3_access, :e_tag_algorithm_family) SENSITIVE = [] include Aws::Structure end |
#propagated_set_level_tags ⇒ Array<String>
The tags keys to propagate to the S3 objects associated with read sets in the sequence store.
9086 9087 9088 9089 9090 9091 9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-omics/types.rb', line 9086 class UpdateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :update_time, :propagated_set_level_tags, :status, :status_message, :fallback_location, :s3_access, :e_tag_algorithm_family) SENSITIVE = [] include Aws::Structure end |
#s3_access ⇒ Types::SequenceStoreS3Access
The S3 access metadata of the sequence store.
9086 9087 9088 9089 9090 9091 9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-omics/types.rb', line 9086 class UpdateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :update_time, :propagated_set_level_tags, :status, :status_message, :fallback_location, :s3_access, :e_tag_algorithm_family) SENSITIVE = [] include Aws::Structure end |
#sse_config ⇒ Types::SseConfig
Server-side encryption (SSE) settings for a store.
9086 9087 9088 9089 9090 9091 9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-omics/types.rb', line 9086 class UpdateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :update_time, :propagated_set_level_tags, :status, :status_message, :fallback_location, :s3_access, :e_tag_algorithm_family) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the sequence store.
9086 9087 9088 9089 9090 9091 9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-omics/types.rb', line 9086 class UpdateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :update_time, :propagated_set_level_tags, :status, :status_message, :fallback_location, :s3_access, :e_tag_algorithm_family) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The status message of the sequence store.
9086 9087 9088 9089 9090 9091 9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-omics/types.rb', line 9086 class UpdateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :update_time, :propagated_set_level_tags, :status, :status_message, :fallback_location, :s3_access, :e_tag_algorithm_family) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The last-updated time of the Sequence Store.
9086 9087 9088 9089 9090 9091 9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-omics/types.rb', line 9086 class UpdateSequenceStoreResponse < Struct.new( :id, :arn, :name, :description, :sse_config, :creation_time, :update_time, :propagated_set_level_tags, :status, :status_message, :fallback_location, :s3_access, :e_tag_algorithm_family) SENSITIVE = [] include Aws::Structure end |