Class: Aws::Omics::Types::UpdateWorkflowRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-omics/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description for the workflow.

Returns:

  • (String)


9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
# File 'lib/aws-sdk-omics/types.rb', line 9294

class UpdateWorkflowRequest < Struct.new(
  :id,
  :name,
  :description,
  :storage_type,
  :storage_capacity,
  :readme_markdown)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The workflow's ID.

Returns:

  • (String)


9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
# File 'lib/aws-sdk-omics/types.rb', line 9294

class UpdateWorkflowRequest < Struct.new(
  :id,
  :name,
  :description,
  :storage_type,
  :storage_capacity,
  :readme_markdown)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A name for the workflow.

Returns:

  • (String)


9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
# File 'lib/aws-sdk-omics/types.rb', line 9294

class UpdateWorkflowRequest < Struct.new(
  :id,
  :name,
  :description,
  :storage_type,
  :storage_capacity,
  :readme_markdown)
  SENSITIVE = []
  include Aws::Structure
end

#readme_markdownString

The markdown content for the workflow's README file. This provides documentation and usage information for users of the workflow.

Returns:

  • (String)


9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
# File 'lib/aws-sdk-omics/types.rb', line 9294

class UpdateWorkflowRequest < Struct.new(
  :id,
  :name,
  :description,
  :storage_type,
  :storage_capacity,
  :readme_markdown)
  SENSITIVE = []
  include Aws::Structure
end

#storage_capacityInteger

The default static storage capacity (in gibibytes) for runs that use this workflow or workflow version.

Returns:

  • (Integer)


9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
# File 'lib/aws-sdk-omics/types.rb', line 9294

class UpdateWorkflowRequest < Struct.new(
  :id,
  :name,
  :description,
  :storage_type,
  :storage_capacity,
  :readme_markdown)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The default storage type for runs that use this workflow. STATIC storage allocates a fixed amount of storage. DYNAMIC storage dynamically scales the storage up or down, based on file system utilization. For more information about static and dynamic storage, see Running workflows in the Amazon Web Services HealthOmics User Guide.

Returns:

  • (String)


9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
# File 'lib/aws-sdk-omics/types.rb', line 9294

class UpdateWorkflowRequest < Struct.new(
  :id,
  :name,
  :description,
  :storage_type,
  :storage_capacity,
  :readme_markdown)
  SENSITIVE = []
  include Aws::Structure
end