Class: Aws::Omics::Types::UpdateWorkflowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::UpdateWorkflowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description for the workflow.
-
#id ⇒ String
The workflow's ID.
-
#name ⇒ String
A name for the workflow.
-
#readme_markdown ⇒ String
The markdown content for the workflow's README file.
-
#storage_capacity ⇒ Integer
The default static storage capacity (in gibibytes) for runs that use this workflow or workflow version.
-
#storage_type ⇒ String
The default storage type for runs that use this workflow.
Instance Attribute Details
#description ⇒ String
A description for the workflow.
9294 9295 9296 9297 9298 9299 9300 9301 9302 9303 |
# File 'lib/aws-sdk-omics/types.rb', line 9294 class UpdateWorkflowRequest < Struct.new( :id, :name, :description, :storage_type, :storage_capacity, :readme_markdown) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The workflow's ID.
9294 9295 9296 9297 9298 9299 9300 9301 9302 9303 |
# File 'lib/aws-sdk-omics/types.rb', line 9294 class UpdateWorkflowRequest < Struct.new( :id, :name, :description, :storage_type, :storage_capacity, :readme_markdown) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the workflow.
9294 9295 9296 9297 9298 9299 9300 9301 9302 9303 |
# File 'lib/aws-sdk-omics/types.rb', line 9294 class UpdateWorkflowRequest < Struct.new( :id, :name, :description, :storage_type, :storage_capacity, :readme_markdown) SENSITIVE = [] include Aws::Structure end |
#readme_markdown ⇒ String
The markdown content for the workflow's README file. This provides documentation and usage information for users of the workflow.
9294 9295 9296 9297 9298 9299 9300 9301 9302 9303 |
# File 'lib/aws-sdk-omics/types.rb', line 9294 class UpdateWorkflowRequest < Struct.new( :id, :name, :description, :storage_type, :storage_capacity, :readme_markdown) SENSITIVE = [] include Aws::Structure end |
#storage_capacity ⇒ Integer
The default static storage capacity (in gibibytes) for runs that use this workflow or workflow version.
9294 9295 9296 9297 9298 9299 9300 9301 9302 9303 |
# File 'lib/aws-sdk-omics/types.rb', line 9294 class UpdateWorkflowRequest < Struct.new( :id, :name, :description, :storage_type, :storage_capacity, :readme_markdown) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
The default storage type for runs that use this workflow. STATIC storage allocates a fixed amount of storage. DYNAMIC storage dynamically scales the storage up or down, based on file system utilization. For more information about static and dynamic storage, see Running workflows in the Amazon Web Services HealthOmics User Guide.
9294 9295 9296 9297 9298 9299 9300 9301 9302 9303 |
# File 'lib/aws-sdk-omics/types.rb', line 9294 class UpdateWorkflowRequest < Struct.new( :id, :name, :description, :storage_type, :storage_capacity, :readme_markdown) SENSITIVE = [] include Aws::Structure end |