Class: Aws::Omics::Types::UpdateWorkflowVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-omics/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

Description of the workflow version.

Returns:

  • (String)


9336
9337
9338
9339
9340
9341
9342
9343
9344
9345
# File 'lib/aws-sdk-omics/types.rb', line 9336

class UpdateWorkflowVersionRequest < Struct.new(
  :workflow_id,
  :version_name,
  :description,
  :storage_type,
  :storage_capacity,
  :readme_markdown)
  SENSITIVE = []
  include Aws::Structure
end

#readme_markdownString

The markdown content for the workflow version's README file. This provides documentation and usage information for users of this specific workflow version.

Returns:

  • (String)


9336
9337
9338
9339
9340
9341
9342
9343
9344
9345
# File 'lib/aws-sdk-omics/types.rb', line 9336

class UpdateWorkflowVersionRequest < Struct.new(
  :workflow_id,
  :version_name,
  :description,
  :storage_type,
  :storage_capacity,
  :readme_markdown)
  SENSITIVE = []
  include Aws::Structure
end

#storage_capacityInteger

The default static storage capacity (in gibibytes) for runs that use this workflow version. The storageCapacity can be overwritten at run time. The storage capacity is not required for runs with a DYNAMIC storage type.

Returns:

  • (Integer)


9336
9337
9338
9339
9340
9341
9342
9343
9344
9345
# File 'lib/aws-sdk-omics/types.rb', line 9336

class UpdateWorkflowVersionRequest < Struct.new(
  :workflow_id,
  :version_name,
  :description,
  :storage_type,
  :storage_capacity,
  :readme_markdown)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The default storage type for runs that use this workflow version. The storageType can be overridden at run time. DYNAMIC storage dynamically scales the storage up or down, based on file system utilization. STATIC storage allocates a fixed amount of storage. For more information about dynamic and static storage types, see Run storage types in the in the Amazon Web Services HealthOmics User Guide .

Returns:

  • (String)


9336
9337
9338
9339
9340
9341
9342
9343
9344
9345
# File 'lib/aws-sdk-omics/types.rb', line 9336

class UpdateWorkflowVersionRequest < Struct.new(
  :workflow_id,
  :version_name,
  :description,
  :storage_type,
  :storage_capacity,
  :readme_markdown)
  SENSITIVE = []
  include Aws::Structure
end

#version_nameString

The name of the workflow version.

Returns:

  • (String)


9336
9337
9338
9339
9340
9341
9342
9343
9344
9345
# File 'lib/aws-sdk-omics/types.rb', line 9336

class UpdateWorkflowVersionRequest < Struct.new(
  :workflow_id,
  :version_name,
  :description,
  :storage_type,
  :storage_capacity,
  :readme_markdown)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_idString

The workflow's ID. The workflowId is not the UUID.

Returns:

  • (String)


9336
9337
9338
9339
9340
9341
9342
9343
9344
9345
# File 'lib/aws-sdk-omics/types.rb', line 9336

class UpdateWorkflowVersionRequest < Struct.new(
  :workflow_id,
  :version_name,
  :description,
  :storage_type,
  :storage_capacity,
  :readme_markdown)
  SENSITIVE = []
  include Aws::Structure
end