Class: Aws::Omics::Types::UpdateWorkflowVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Omics::Types::UpdateWorkflowVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-omics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
Description of the workflow version.
-
#readme_markdown ⇒ String
The markdown content for the workflow version’s README file.
-
#storage_capacity ⇒ Integer
The default static storage capacity (in gibibytes) for runs that use this workflow version.
-
#storage_type ⇒ String
The default storage type for runs that use this workflow version.
-
#version_name ⇒ String
The name of the workflow version.
-
#workflow_id ⇒ String
The workflow’s ID.
Instance Attribute Details
#description ⇒ String
Description of the workflow version.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 |
# File 'lib/aws-sdk-omics/types.rb', line 9336 class UpdateWorkflowVersionRequest < Struct.new( :workflow_id, :version_name, :description, :storage_type, :storage_capacity, :readme_markdown) SENSITIVE = [] include Aws::Structure end |
#readme_markdown ⇒ String
The markdown content for the workflow version’s README file. This provides documentation and usage information for users of this specific workflow version.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 |
# File 'lib/aws-sdk-omics/types.rb', line 9336 class UpdateWorkflowVersionRequest < Struct.new( :workflow_id, :version_name, :description, :storage_type, :storage_capacity, :readme_markdown) SENSITIVE = [] include Aws::Structure end |
#storage_capacity ⇒ Integer
The default static storage capacity (in gibibytes) for runs that use this workflow version. The ‘storageCapacity` can be overwritten at run time. The storage capacity is not required for runs with a `DYNAMIC` storage type.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 |
# File 'lib/aws-sdk-omics/types.rb', line 9336 class UpdateWorkflowVersionRequest < Struct.new( :workflow_id, :version_name, :description, :storage_type, :storage_capacity, :readme_markdown) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
The default storage type for runs that use this workflow version. The ‘storageType` can be overridden at run time. `DYNAMIC` storage dynamically scales the storage up or down, based on file system utilization. STATIC storage allocates a fixed amount of storage. For more information about dynamic and static storage types, see [Run storage types] in the in the Amazon Web Services HealthOmics User Guide .
[1]: docs.aws.amazon.com/omics/latest/dev/workflows-run-types.html
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 |
# File 'lib/aws-sdk-omics/types.rb', line 9336 class UpdateWorkflowVersionRequest < Struct.new( :workflow_id, :version_name, :description, :storage_type, :storage_capacity, :readme_markdown) SENSITIVE = [] include Aws::Structure end |
#version_name ⇒ String
The name of the workflow version.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 |
# File 'lib/aws-sdk-omics/types.rb', line 9336 class UpdateWorkflowVersionRequest < Struct.new( :workflow_id, :version_name, :description, :storage_type, :storage_capacity, :readme_markdown) SENSITIVE = [] include Aws::Structure end |
#workflow_id ⇒ String
The workflow’s ID. The ‘workflowId` is not the UUID.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 |
# File 'lib/aws-sdk-omics/types.rb', line 9336 class UpdateWorkflowVersionRequest < Struct.new( :workflow_id, :version_name, :description, :storage_type, :storage_capacity, :readme_markdown) SENSITIVE = [] include Aws::Structure end |