Class: Aws::Omics::Waiters::WorkflowVersionActive
- Inherits:
-
Object
- Object
- Aws::Omics::Waiters::WorkflowVersionActive
- Defined in:
- lib/aws-sdk-omics/waiters.rb,
sig/waiters.rbs
Overview
Wait until a workflow version is active.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ WorkflowVersionActive
constructor
A new instance of WorkflowVersionActive.
-
#wait(params = {}) ⇒ Types::GetWorkflowVersionResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ WorkflowVersionActive
Returns a new instance of WorkflowVersionActive.
1170 1171 |
# File 'lib/aws-sdk-omics/waiters.rb', line 1170
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1214 1215 1216 |
# File 'lib/aws-sdk-omics/waiters.rb', line 1214 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetWorkflowVersionResponse
Returns a response object which responds to the following methods:
- #arn => String
- #workflow_id => String
- #version_name => String
- #accelerators => String
- #creation_time => Time
- #description => String
- #definition => String
- #digest => String
- #engine => String
- #main => String
- #metadata => Hash<String,String>
- #parameter_template => Hash<String,Types::WorkflowParameter>
- #status => String
- #status_message => String
- #storage_type => String
- #storage_capacity => Integer
- #type => String
- #tags => Hash<String,String>
- #uuid => String
- #workflow_bucket_owner_id => String
- #container_registry_map => Types::ContainerRegistryMap
- #readme => String
- #definition_repository_details => Types::DefinitionRepositoryDetails
- #readme_path => String
- #profiles => Array<String>
- #profile_parameter_templates => Hash<String,Hash<String,Types::WorkflowParameter>>
1209 |
# File 'lib/aws-sdk-omics/waiters.rb', line 1209
def wait: (
|